(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25599,        652]*)
(*NotebookOutlinePosition[     26364,        678]*)
(*  CellTagsIndexPosition[     26320,        674]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Numerical computation features for ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" 5.0",
    FontColor->RGBColor[0, 0, 1]]
}], "Chapter",
  TextAlignment->Center],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" 5.0 \:306e\:6570\:5024\:8a08\:7b97\:306e\:7279\:5fb4",
    FontColor->RGBColor[0, 0, 1]]
}], "Chapter",
  TextAlignment->Center],

Cell["\:7ffb\:8a33\:5354\:529b JMUG", "Text",
  TextAlignment->Center,
  FontSize->14],

Cell[CellGroupData[{

Cell["Initialization", "SubsubsectionIcon",
  FontColor->RGBColor[0.310018, 0.560006, 1.5259*^-05]],

Cell[BoxData[{
    \(\(\(KernelStyle[_]\)[Null] := Null;\)\), "\n", 
    \(\(\(KernelStyle[k_String]\)[x_] := 
        CellPrint[
          Cell[BoxData[MakeBoxes[x]], StringJoin["\<Output \>", k], 
            CellLabel \[Rule] 
              StringJoin["\<Mathematica  \>", k, "\< Out[ \>", 
                ToString[$Line], "\<]= \>"]]];\)\), "\[IndentingNewLine]", 
    \(\($Post\  = \ KernelStyle[ToString[$VersionNumber]];\)\)}], "Input 4.2",\

  CellLabel->"In[1]:=",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input",
  CellLabel->"In[1]:=",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input 4.2",
  CellLabel->"In[4]:=",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SetAttributes[AverageTiming, \ HoldAll];\)\), "\[IndentingNewLine]", 
    \(AverageTiming[expr_]\  := \ 
      Module[{tries\  = \ 1, \ t}, 
        Times[Block[{Second\  = \ 1}, 
            t\  = \ First[Timing[expr]]; \[IndentingNewLine]While[
              t\  < \ 1, \ tries\  *= \ 2; \ 
              t\  = \ First[
                  Timing[Do[expr, \ {tries}]]]]; \[IndentingNewLine]t/
              tries]\ , Second]]\)}], "Input",
  CellLabel->"In[3]:=",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SetAttributes[AverageTiming, \ HoldAll];\)\), "\[IndentingNewLine]", 
    \(AverageTiming[expr_]\  := \ 
      Module[{tries\  = \ 1, \ t}, 
        Times[Block[{Second\  = \ 1}, 
            t\  = \ First[Timing[expr]]; \[IndentingNewLine]While[
              t\  < \ 1, \ tries\  *= \ 2; \ 
              t\  = \ First[
                  Timing[Do[expr, \ {tries}]]]]; \[IndentingNewLine]t/
              tries]\ , Second]]\)}], "Input 4.2",
  CellLabel->"In[6]:=",
  InitializationCell->True],

Cell[BoxData[
    \(Needs["\<Optimization`UnconstrainedProblems`\>"]\)], "Input",
  CellLabel->"In[5]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(AppendTo[$Path, \ "\<C:\\Documents and Settings\\rknapp\\My Documents\
\\Talks\\2003 Developer Conference\\Data\>"];\)\)], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Overview \:ff08\:6982\:8981\:ff09", "SubsectionIcon",
  FontColor->RGBColor[0.310018, 0.560006, 1.5259*^-5]],

Cell[TextData[{
  "For ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0, nearly all numerical computation functions were improved and several \
were improved significantly with numerous added features.  There are too many \
features to cover them all in this talk, so I'll keep my focus on just a few \
highlights."
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 \:3067\:306f\:ff0c\:307b\:3068\:3093\:3069\:3059\:3079\:3066\:306e\
\:6570\:5024\:8a08\:7b97\:95a2\:6570\:304c\:6539\:826f\:3055\:308c\:ff0c\:305d\
\:306e\:3046\:3061\:306e\:3042\:308b\:3082\:306e\:306f\:6a5f\:80fd\:3082\:4ed8\
\:52a0\:3055\:308c\:3066\:5927\:5e45\:306b\:6539\:826f\:3055\:308c\:307e\:3057\
\:305f\:ff0e\:3053\:306e\:8b1b\:6f14\:3067\:306f\:3059\:3079\:3066\:3092\:89e3\
\:8aac\:3067\:304d\:306a\:3044\:306e\:3067\:ff0c\:4ee3\:8868\:7684\:306a\:3082\
\:306e\:3044\:304f\:3064\:304b\:3092\:7d39\:4ecb\:3057\:307e\:3059\:ff0e"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["\[Bullet]",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" Speed improvements to arbitrary precision and large integer \
arithmetic. \n\:ff08\:4efb\:610f\:7cbe\:5ea6\:5b9f\:6570\:304a\:3088\:3073\
\:5927\:304d\:3044\:6574\:6570\:306e\:8a08\:7b97\:306b\:304a\:3051\:308b\:901f\
\:5ea6\:5411\:4e0a\:ff09",
    FontColor->GrayLevel[0.333333]]
}], "SubsubsectionIcon"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 use the ",
  ButtonBox["GMP",
    ButtonData:>{
      URL[ "http://www.swox.com/gmp/"], None},
    ButtonStyle->"Hyperlink"],
  " library to achieve arithmetic optimizations for multiplication and \
addition of arbitrary precision numbers are large integers.  The library has \
machine optimized code, some in assembler, for doing basic operations needed \
for arbitrary sized arithmetic.  The interface for arithmetic is still \
seamless, so all you should notice are time and memory performance \
improvements."
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 \:306f\:ff0c\:4efb\:610f\:7cbe\:5ea6\:5b9f\:6570\:304a\:3088\:3073\
\:5927\:304d\:3044\:6574\:6570\:306e\:548c\:3068\:7a4d\:306e\:8a08\:7b97\:306e\
\:6700\:9069\:5316\:306e\:305f\:3081 ",
  ButtonBox["GMP",
    ButtonData:>{
      URL[ "http://www.swox.com/gmp/"], None},
    ButtonStyle->"Hyperlink"],
  " \:30e9\:30a4\:30d6\:30e9\:30ea\:3092\:4f7f\:3044\:307e\:3059\:ff0e\:3053\
\:306e\:30e9\:30a4\:30d6\:30e9\:30ea\:306f\:ff0c\:4efb\:610f\:7cbe\:5ea6\:5b9f\
\:6570\:306e\:57fa\:672c\:7684\:6f14\:7b97\:306b\:ff0c\:4e00\:90e8\:30a2\:30bb\
\:30f3\:30d6\:30e9\:3092\:4f7f\:3063\:305f\:30de\:30b7\:30f3\:6700\:9069\:5316\
\:30b3\:30fc\:30c9\:3092\:6301\:3063\:3066\:3044\:307e\:3059\:ff0e\:3053\:306e\
\:6f14\:7b97\:306e\:30a4\:30f3\:30bf\:30fc\:30d5\:30a7\:30a4\:30b9\:306f\:4ee5\
\:524d\:306e\:3082\:306e\:3068\:540c\:69d8\:3067\:ff0c\:30e6\:30fc\:30b6\:30fc\
\:304c\:6c17\:3065\:304f\:306e\:306f\:8a08\:7b97\:6642\:9593\:3068\:4f7f\:7528\
\:30e1\:30e2\:30ea\:30fc\:306e\:6e1b\:5c11\:3060\:3051\:3067\:3059\:ff0e"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["\[Bullet]",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox["Dense linear algebra converted to use LAPACK with special machine \
optimized BLAS. \n\
\:ff08\:5bc6\:306a\:7dda\:5f62\:4ee3\:6570\:306b\:304a\:3051\:308b\:30de\:30b7\
\:30f3\:6700\:9069\:5316 BLAS \:306b\:57fa\:3065\:304f LAPACK \:306e\:4f7f\
\:7528\:ff09",
    FontColor->GrayLevel[0.333333]]
}], "SubsubsectionIcon"],

Cell[TextData[{
  "For numerical linear algebra, LAPACK (Linear Algebra PACKage) has become \
the library of choice.  LAPACK evolved from LINPACK which is what numerical \
linear algebra in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2 and earlier is based on.  A basic idea of LAPACK was to build the \
library on top of  small basic commonly needed operations which were simple \
enough that they could be optimized for a particular machine architecture.  \
These Basic Linear Algebra Subroutines (BLAS) form the core of LAPACK.  \
LAPACK further improves on LINPACK by using block algorithms to get better \
performance and by using more robust numerical algorithms.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s higher level linear algebra functions provide a platform independent \
interface to LAPACK which runs with special machine optimized BLAS libraries \
for the many platforms we support."
}], "Text"],

Cell[TextData[{
  "\:7dda\:5f62\:4ee3\:6570\:306e\:6570\:5024\:8a08\:7b97\:306b\:ff0c LAPACK \
(Linear Algebra PACKage) \:30e9\:30a4\:30d6\:30e9\:30ea\:304c\:4f7f\:308f\
\:308c\:308b\:3088\:3046\:306b\:306a\:308a\:307e\:3057\:305f\:ff0e LAPACK \
\:306f ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2 \:4ee5\:524d\:306e\:7dda\:5f62\:4ee3\:6570\:306e\:6570\:5024\:8a08\
\:7b97\:306b\:4f7f\:308f\:308c\:3066\:3044\:305f\:30e9\:30a4\:30d6\:30e9\:30ea\
 LINPACK \:304b\:3089\:767a\:5c55\:3057\:305f\:3082\:306e\:3067\:3059\:ff0e \
LAPACK \:306b\:304a\:3051\:308b\:57fa\:672c\:7684\:306a\:30a2\:30a4\:30c7\
\:30a2\:306f\:ff0c\:5171\:901a\:306b\:4f7f\:308f\:308c\:308b\:5c0f\:3055\:306a\
\:57fa\:672c\:7684\:306a\:6f14\:7b97\:306b\:57fa\:3065\:3044\:3066\:30e9\:30a4\
\:30d6\:30e9\:30ea\:3092\:7d44\:307f\:4e0a\:3052\:308b\:3068\:3044\:3046\:3082\
\:306e\:3067\:ff0c\:5404\:90e8\:5206\:306f\:5358\:7d14\:3067\:3042\:308b\:305f\
\:3081\:306b\:ff0c\:500b\:3005\:306e\:30de\:30b7\:30f3\:30a2\:30fc\:30ad\:30c6\
\:30af\:30c1\:30e3\:306b\:6700\:9069\:5316\:3059\:308b\:3053\:3068\:304c\:3067\
\:304d\:308b\:306e\:3067\:3059\:ff0e\:3053\:308c\:3089\:306e\:7dda\:5f62\:4ee3\
\:6570\:30b5\:30d6\:30eb\:30fc\:30c1\:30f3 (BLAS) \:304c LAPACK \:306e\:6838\
\:3092\:6210\:3057\:3066\:3044\:307e\:3059\:ff0e LAPACK \:306f\:3055\:3089\
\:306b\:ff0c\:9ad8\:80fd\:7387\:306a\:30d6\:30ed\:30c3\:30af\:30a2\:30eb\:30b4\
\:30ea\:30ba\:30e0\:3068\:30ed\:30d0\:30b9\:30c8\:306a\:6570\:5024\:8a08\:7b97\
\:30a2\:30eb\:30b4\:30ea\:30ba\:30e0\:3092\:4f7f\:3063\:3066\:ff0cLINPACK \
\:3092\:3088\:308a\:6539\:5584\:3059\:308b\:3082\:306e\:306b\:306a\:3063\:3066\
\:3044\:307e\:3059\:ff0e ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \:306e\:9ad8\:30ec\:30d9\:30eb\:7dda\:5f62\:4ee3\:6570\:95a2\:6570\:306f \
LAPACK \:306e\:30d7\:30e9\:30c3\:30c8\:30d5\:30a9\:30fc\:30e0\:975e\:4f9d\
\:5b58\:306a\:30a4\:30f3\:30bf\:30fc\:30d5\:30a7\:30a4\:30b9\:3092\:63d0\:4f9b\
\:3057\:ff0cLAPACK \:306f ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \:304c\:30b5\:30dd\:30fc\:30c8\:3059\:308b\:305f\:304f\:3055\:3093\:306e\
\:30d7\:30e9\:30c3\:30c8\:30d5\:30a9\:30fc\:30e0\:306b\:7279\:5225\:306b\:30de\
\:30b7\:30f3\:6700\:9069\:5316\:3055\:308c\:305f BLAS \
\:30e9\:30a4\:30d6\:30e9\:30ea\:3092\:99c6\:52d5\:3059\:308b\:3068\:3044\:3046\
\:308f\:3051\:3067\:3059\:ff0e"
}], "Text"],

Cell["\<\
We have gone a step further and applied this model to some of our arbitrary \
precision numerical linear algebra routines.  \
\>", "Text"],

Cell["\<\
\:308f\:308c\:308f\:308c\:306f\:3053\:306e\:30e2\:30c7\:30eb\:3092\:3055\:3089\
\:306b\:767a\:5c55\:3055\:305b\:ff0c\:3044\:304f\:3064\:304b\:306e\:4efb\:610f\
\:7cbe\:5ea6\:6570\:5024\:7dda\:5f62\:4ee3\:6570\:306e\:30eb\:30fc\:30c1\:30f3\
\:306b\:3082\:5fdc\:7528\:3057\:3066\:3044\:307e\:3059\:ff0e\
\>", "Text"],

Cell[TextData[{
  "While the additional robustness of LAPACK will no doubt be appreciated, \
what most of you will notice is the ",
  ButtonBox["speed",
    ButtonData:>{"LAPACK.nb", None},
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[TextData[{
  "LAPACK \:306e\:6539\:826f\:3055\:308c\:305f\:30ed\:30d0\:30b9\:30c8\:306a\
\:7279\:6027\:306f\:3082\:3061\:308d\:3093\:3068\:3057\:3066\:ff0c\:30e6\:30fc\
\:30b6\:30fc\:304c\:6700\:3082\:611f\:3058\:308b\:306e\:306f\:305d\:306e ",
  ButtonBox["speed",
    ButtonData:>{"LAPACK.nb", None},
    ButtonStyle->"Hyperlink"],
  "  \:3067\:3057\:3087\:3046\:ff0e"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["\[Bullet]",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox["SparseArray objects that support sparse linear algebra, \
arithmetic, and other operations.\n\:ff08\:758e\:884c\:5217\:7dda\:5f62\:4ee3\
\:6570\:306b\:4f7f\:308f\:308c\:308b SparseArray \:30aa\:30d6\:30b8\:30a7\
\:30af\:30c8\:ff09",
    FontColor->GrayLevel[0.333333]]
}], "SubsubsectionIcon"],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0, an new data structure which supports sparse matrices has been \
introduced.  ",
  StyleBox["SparseArray", "MR"],
  " objects provide a data structure which is a sparse representation for \
arrays of any dimensions.  As a new piece in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " language, the representation has been integrated into the system in a \
thorough way."
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 \:306b\:306f\:758e\:884c\:5217\:3092\:6271\:3046\:65b0\:305f\:306a\
\:30c7\:30fc\:30bf\:69cb\:9020\:304c\:5c0e\:5165\:3055\:308c\:307e\:3057\:305f\
\:ff0e",
  StyleBox["SparseArray", "MR"],
  " \:30aa\:30d6\:30b8\:30a7\:30af\:30c8\:306f\:4efb\:610f\:6b21\:5143\:306e\
\:914d\:5217\:306e\:758e\:306a\:8868\:73fe\:3067\:3042\:308b\:30c7\:30fc\:30bf\
\:69cb\:9020\:3092\:63d0\:4f9b\:3057\:307e\:3059\:ff0e\:3053\:306e\:8868\:73fe\
\:306f ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \:8a00\:8a9e\:306e\:65b0\:305f\:306a\:ff11\:8a9e\:3068\:3057\:3066\:30b7\
\:30b9\:30c6\:30e0\:306b\:5b8c\:74a7\:306a\:5f62\:3067\:7d71\:5408\:3055\:308c\
\:3066\:3044\:307e\:3059\:ff0e"
}], "Text"],

Cell[TextData[{
  "I will use some ",
  ButtonBox["examples",
    ButtonData:>{"Sparse.nb", None},
    ButtonStyle->"Hyperlink"],
  " to give you an idea of how ",
  StyleBox["SparseArray", "MR"],
  " objects work and are integrated into the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " system."
}], "Text"],

Cell[TextData[{
  "\:3053\:3053\:3067\:306f\:ff0c\:3044\:304f\:3064\:304b\:306e ",
  ButtonBox["examples",
    ButtonData:>{"Sparse.nb", None},
    ButtonStyle->"Hyperlink"],
  " \:306b\:3088\:3063\:3066\:ff0c",
  StyleBox["SparseArray", "MR"],
  " \:30aa\:30d6\:30b8\:30a7\:30af\:30c8\:304c\:3069\:306e\:3088\:3046\:306b\
\:6a5f\:80fd\:3057\:ff0c\:3069\:306e\:3088\:3046\:306b ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \:30b7\:30b9\:30c6\:30e0\:7d71\:5408\:3055\:308c\:3066\:3044\:308b\:304b\
\:3092\:793a\:3057\:307e\:3059\:ff0e"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["\[Bullet]",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox["Large scale linear programming and integration of NMinimize into \
the kernel.\n\:ff08\:5927\:898f\:6a21\:306a\:7dda\:5f62\:8a08\:753b\:6cd5\
\:3068 NMinimize \
\:306e\:30ab\:30fc\:30cd\:30eb\:3078\:306e\:7d71\:5408\:ff09",
    FontColor->GrayLevel[0.333333]]
}], "SubsubsectionIcon"],

Cell[TextData[{
  "One of the areas driving the development of the",
  StyleBox[" SparseArray", "MR"],
  " objects was linear programming, where an interior point method has been \
developed along with some additional enhancements to linear programming."
}], "Text"],

Cell[TextData[{
  StyleBox["SparseArray", "MR"],
  " \:30aa\:30d6\:30b8\:30a7\:30af\:30c8\:958b\:767a\:306e\:5951\:6a5f\:3068\
\:306a\:3063\:305f\:5206\:91ce\:306e\:ff11\:3064\:306f\:7dda\:5f62\:8a08\:753b\
\:6cd5\:3067\:3059\:304c\:ff0c\:305d\:3053\:3067\:306f\:7dda\:5f62\:8a08\:753b\
\:6cd5\:306e\:5f37\:5316\:306b\:52a0\:3048\:3066\:5185\:90e8\:70b9\:6cd5\:3092\
\:767a\:5c55\:3055\:305b\:307e\:3057\:305f\:ff0e"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["\[Bullet]",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox["EvaluationMonitor and StepMonitor options which allow you to \
monitor progress of numerical computations.\n\:ff08EvaluationMonitor \:3068 \
StepMonitor \
\:30aa\:30d7\:30b7\:30e7\:30f3\:306b\:3088\:308b\:6570\:5024\:8a08\:7b97\:5b9f\
\:884c\:72b6\:6cc1\:306e\:76e3\:8996\:ff09",
    FontColor->GrayLevel[0.333333]]
}], "SubsubsectionIcon"],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 the ",
  StyleBox["EvaluationMonitor", "MR"],
  " and ",
  StyleBox["StepMonitor", "MR"],
  " options have been added to several functions to allow you to follow the \
progress of various numerical algorithms.   I will show you some ",
  ButtonBox["examples",
    ButtonData:>{"Monitors.nb", None},
    ButtonStyle->"Hyperlink"],
  " of how these work."
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 \:306b\:306f\:3044\:304f\:3064\:304b\:306e\:95a2\:6570\:306b ",
  StyleBox["EvaluationMonitor", "MR"],
  " \:3068 ",
  StyleBox["StepMonitor", "MR"],
  " \:30aa\:30d7\:30b7\:30e7\:30f3\:304c\:8ffd\:52a0\:3055\:308c\:ff0c\:3055\
\:307e\:3056\:307e\:306a\:6570\:5024\:30a2\:30eb\:30b4\:30ea\:30ba\:30e0\:306e\
\:9032\:884c\:72b6\:6cc1\:3092\:76e3\:8996\:3059\:308b\:3053\:3068\:304c\:3067\
\:304d\:307e\:3059\:ff0e\:305d\:306e\:3044\:304f\:3064\:304b\:306e ",
  ButtonBox["examples",
    ButtonData:>{"Monitors.nb", None},
    ButtonStyle->"Hyperlink"],
  " \:3092\:793a\:3057\:307e\:3059\:ff0e"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Vector valued variables in several functions.\n\:ff08\:3044\:304f\
\:3064\:304b\:306e\:95a2\:6570\:306b\:304a\:3051\:308b\:30d9\:30af\:30c8\:30eb\
\:5024\:5909\:6570\:ff09",
    FontColor->GrayLevel[0.333333]]
}], "SubsubsectionIcon"],

Cell[TextData[{
  " ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 includes many new state of the art algorithms.  Some of these are \
really only effective for large scale problems.  Sometimes the most natural \
way to pose large problems are through (black box) functions which operate on \
vectors.  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0, some of the numerical functions are able to interpret some or all of \
their variables as vectors, based on initial conditions.  It is probably \
easiest to see how it works through some ",
  ButtonBox["examples",
    ButtonData:>{"VectorVariables.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  " ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 \:306b\:306f\:3044\:304f\:3064\:304b\:306e\:82b8\:8853\:7684\:3068\
\:3082\:3044\:3048\:308b\:30a2\:30eb\:30b4\:30ea\:30ba\:30e0\:304c\:542b\:307e\
\:308c\:3066\:3044\:307e\:3059\:ff0e\:305d\:306e\:3046\:3061\:306e\:3044\:304f\
\:3064\:304b\:306f\:5b9f\:969b\:306b\:306f\:5927\:898f\:6a21\:306a\:554f\:984c\
\:306b\:306e\:307f\:6709\:52b9\:3067\:3059\:ff0e\:5927\:898f\:6a21\:306a\:554f\
\:984c\:3092\:6271\:3046\:6700\:3082\:81ea\:7136\:306a\:65b9\:6cd5\:306f\:ff0c\
\:30d9\:30af\:30c8\:30eb\:306b\:4f5c\:7528\:3059\:308b\:ff08\:30d6\:30e9\:30c3\
\:30af\:30dc\:30c3\:30af\:30b9\:ff09\:95a2\:6570\:3092\:4f7f\:3046\:3053\:3068\
\:3067\:3059\:ff0e",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 \:3067\:306f\:ff0c\:3042\:308b\:6570\:5024\:6f14\:7b97\:95a2\:6570\
\:306f\:ff0c\:521d\:671f\:5024\:306b\:57fa\:3065\:3044\:3066\:305d\:306e\:4e00\
\:90e8\:ff0c\:307e\:305f\:306f\:3059\:3079\:3066\:306e\:5909\:6570\:3092\:30d9\
\:30af\:30c8\:30eb\:3068\:898b\:306a\:3059\:3053\:3068\:304c\:3067\:304d\:307e\
\:3059\:ff0e\:5b9f\:969b\:306e ",
  ButtonBox["examples",
    ButtonData:>{"VectorVariables.nb", None},
    ButtonStyle->"Hyperlink"],
  " \:306b\:3088\:3063\:3066\:898b\:308b\:65b9\:304c\:308f\:304b\:308a\:3084\
\:3059\:3044\:3067\:3057\:3087\:3046\:ff0e"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["\[Bullet]",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox["Overall NDSolve improvements; DAEs, 1 + n dimensional PDEs, over \
10 new methods, and a flexible framework for adding new, specialized methods.\
\n\:ff08NDSolve \:5168\:822c\:306b\:308f\:305f\:308b\:6539\:826f\:ff0e1 + n \
\:6b21\:5143 PDE \:306e 10 \:4ee5\:4e0a\:306e\:65b0\:3057\:3044\:89e3\:6cd5\
\:3068\:ff0c\:7279\:5225\:306a\:65b9\:6cd5\:3092\:4e0d\:53ef\:3059\:308b\:67d4\
\:8edf\:306a\:67a0\:7d44\:307f\:ff09",
    FontColor->GrayLevel[0.333333]]
}], "SubsubsectionIcon"],

Cell[TextData[{
  "For ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 the NDSolve command was completely restructured into a new framework. \
 There are numerous advantages, including speed improvements, especially for \
large systems, many new methods, and flexibility both in user capability of \
adding specialized methods and in controlling iterations.  There is only time \
to show a small glimpse of what is possible.  I will show a few ",
  ButtonBox["examples",
    ButtonData:>{"NDSolve.nb", None},
    ButtonStyle->"Hyperlink"],
  " which highlight some interesting aspects of the new potential with \
NDSolve."
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 \:3067\:306f\:ff0cNDSolve \:95a2\:6570\:306f\:65b0\:3057\:3044\:67a0\
\:7d44\:307f\:306b\:3059\:3063\:304b\:308a\:751f\:307e\:308c\:5909\:308f\:308a\
\:307e\:3057\:305f\:ff0e\:6642\:9593\:306e\:77ed\:7e2e\:4ee5\:5916\:306b\:3082\
\:ff0c\:3068\:304f\:306b\:5927\:304d\:306a\:30b7\:30b9\:30c6\:30e0\:306b\:3064\
\:3044\:3066\:ff0c\:65b0\:305f\:306a\:89e3\:6cd5\:3084\:7279\:5225\:306a\:65b9\
\:6cd5\:3068\:9010\:6b21\:8a08\:7b97\:306e\:5236\:5fa1\:3092\:6307\:5b9a\:3067\
\:304d\:308b\:6a5f\:80fd\:304c\:53d6\:308a\:5165\:308c\:3089\:308c\:307e\:3057\
\:305f\:ff0e\:3053\:308c\:3089\:306b\:3064\:3044\:3066\:4f55\:304c\:53ef\:80fd\
\:306b\:306a\:3063\:305f\:306e\:304b\:ff0c\:89e3\:8aac\:3059\:308b\:6642\:9593\
\:306f\:308f\:305a\:304b\:3057\:304b\:3042\:308a\:307e\:305b\:3093\:ff0e\
NDSolve \:3067\:4f55\:304c\:3067\:304d\:308b\:3088\:3046\:306b\:306a\:3063\
\:305f\:306e\:304b\:ff0c\:3044\:304f\:3064\:304b\:306e ",
  ButtonBox["examples",
    ButtonData:>{"NDSolve.nb", None},
    ButtonStyle->"Hyperlink"],
  " \:3092\:793a\:3057\:307e\:3059\:ff0e"
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Summary
\:ff08\:8981\:7d04\:ff09\
\>", "SubsectionIcon",
  FontColor->RGBColor[0.310018, 0.560006, 1.5259*^-5]],

Cell[TextData[{
  "There are three different themes running through many of the features I \
have demonstrated above.  First, we are actively looking into the use of \
highly optimized libraries to get the best  speed possible for basic \
operations on the wide variety of platforms we support.  Second, we are \
actively pursuing algorithm development which will allow you to pursue large \
and large sized problems with efficient, robust methods.  Finally, we are \
making many of the building blocks for the higher level algorithms, such as \
SparseArrays, available as features to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users.  In the future, you should expect to see similar development in \
further areas with successive versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[TextData[{
  "\:4ee5\:4e0a\:8aac\:660e\:3057\:305f\:3053\:3068\:306e\:4e2d\:306b\:306f\
\:ff13\:3064\:306e\:7570\:306a\:308b\:30c6\:30fc\:30de\:304c\:3042\:308a\:307e\
\:3059\:ff0e\:ff11\:3064\:306f\:ff0c\:3055\:307e\:3056\:307e\:306a\:30d7\:30e9\
\:30c3\:30c8\:30d5\:30a9\:30fc\:30e0\:306b\:304a\:3044\:3066\:ff0c\:6700\:901f\
\:306e\:57fa\:672c\:6f14\:7b97\:3092\:5b9f\:73fe\:3059\:308b\:6700\:9069\:5316\
\:30e9\:30a4\:30d6\:30e9\:30ea\:306e\:5229\:7528\:3067\:3059\:ff0e\:7b2c\:ff12\
\:306b\:ff0c\:5927\:898f\:6a21\:306a\:8a08\:7b97\:306b\:304a\:3051\:308b\:52b9\
\:7387\:7684\:3067\:30ed\:30d0\:30b9\:30c8\:306a\:65b9\:6cd5\:3092\:8ffd\:6c42\
\:3067\:304d\:308b\:30a2\:30eb\:30b4\:30ea\:30ba\:30e0\:306e\:958b\:767a\:3067\
\:3059\:ff0e\:305d\:3057\:3066\:7b2c\:ff13\:306b\:ff0cSparseArray \
\:306e\:3088\:3046\:306a\:30cf\:30a4\:30ec\:30d9\:30eb\:306a\:69cb\:9020\:30d6\
\:30ed\:30c3\:30af\:3092 ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \:306e\:30aa\:30d6\:30b8\:30a7\:30af\:30c8\:3068\:3057\:3066\:69cb\:7bc9\
\:3059\:308b\:3053\:3068\:3067\:3059\:ff0e ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \:306e\:5c06\:6765\:30d0\:30fc\:30b8\:30e7\:30f3\:3067\:306f\:ff0c\:3082\
\:3063\:3068\:3055\:307e\:3056\:307e\:306a\:9818\:57df\:306b\:304a\:3044\:3066\
\:540c\:69d8\:306a\:767a\:5c55\:3092\:671f\:5f85\:3059\:308b\:3053\:3068\:304c\
\:3067\:304d\:307e\:3059\:ff0e"
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 742}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Brackets",
WindowSize->{983, 695},
WindowMargins->{{-1, Automatic}, {Automatic, 1}},
Magnification->1.5,
StyleDefinitions -> "5.0 Numerics Style.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 279, 9, 125, "Chapter"],
Cell[2058, 64, 243, 7, 125, "Chapter"],
Cell[2304, 73, 86, 2, 35, "Text"],

Cell[CellGroupData[{
Cell[2415, 79, 99, 1, 35, "SubsubsectionIcon"],
Cell[2517, 82, 502, 11, 163, "Input 4.2",
  InitializationCell->True],
Cell[3022, 95, 170, 4, 63, "Input",
  InitializationCell->True],
Cell[3195, 101, 174, 4, 91, "Input 4.2",
  InitializationCell->True],
Cell[3372, 107, 514, 11, 111, "Input",
  InitializationCell->True],
Cell[3889, 120, 518, 11, 187, "Input 4.2",
  InitializationCell->True],
Cell[4410, 133, 133, 3, 39, "Input",
  InitializationCell->True],
Cell[4546, 138, 205, 4, 39, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4788, 147, 114, 1, 39, "SubsectionIcon"],
Cell[4905, 150, 341, 8, 78, "Text"],
Cell[5249, 160, 629, 10, 78, "Text"],

Cell[CellGroupData[{
Cell[5903, 174, 411, 9, 66, "SubsubsectionIcon"],
Cell[6317, 185, 601, 14, 100, "Text"],
Cell[6921, 201, 1102, 19, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8060, 225, 431, 11, 66, "SubsubsectionIcon"],
Cell[8494, 238, 946, 17, 188, "Text"],
Cell[9443, 257, 2379, 38, 210, "Text"],
Cell[11825, 297, 148, 3, 34, "Text"],
Cell[11976, 302, 324, 5, 56, "Text"],
Cell[12303, 309, 240, 7, 34, "Text"],
Cell[12546, 318, 387, 8, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12970, 331, 405, 10, 89, "SubsubsectionIcon"],
Cell[13378, 343, 481, 13, 78, "Text"],
Cell[13862, 358, 767, 16, 78, "Text"],
Cell[14632, 376, 321, 11, 56, "Text"],
Cell[14956, 389, 560, 13, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15553, 407, 396, 10, 66, "SubsubsectionIcon"],
Cell[15952, 419, 266, 5, 56, "Text"],
Cell[16221, 426, 428, 7, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16686, 438, 452, 11, 89, "SubsubsectionIcon"],
Cell[17141, 451, 450, 14, 56, "Text"],
Cell[17594, 467, 681, 15, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18312, 487, 340, 8, 66, "SubsubsectionIcon"],
Cell[18655, 497, 694, 17, 100, "Text"],
Cell[19352, 516, 1368, 25, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20757, 546, 592, 12, 112, "SubsubsectionIcon"],
Cell[21352, 560, 649, 14, 100, "Text"],
Cell[22004, 576, 1140, 19, 100, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23193, 601, 121, 4, 89, "SubsectionIcon"],
Cell[23317, 607, 833, 16, 144, "Text"],
Cell[24153, 625, 1418, 23, 122, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

