(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    101319,       2978]*)
(*NotebookOutlinePosition[    103558,       3043]*)
(*  CellTagsIndexPosition[    103374,       3033]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["\<\
This loads a package which uses JLink for plotting solutions of PDEs.  A \
system setting is chosen so that the examples below will use machine numbers \
for the calculations.\
\>", "MathCaption"],

Cell["\<\
JLink \:3092\:4f7f\:3063\:3066\:504f\:5fae\:5206\:65b9\:7a0b\:5f0f\:306e\:89e3\
\:3092\:30d7\:30ed\:30c3\:30c8\:3059\:308b\:30d1\:30c3\:30b1\:30fc\:30b8\:3092\
\:30ed\:30fc\:30c9\:3057\:307e\:3059\:ff0e\:4ee5\:4e0b\:306e\:4f8b\:3092\:6a5f\
\:68b0\:7cbe\:5ea6\:5b9f\:6570\:3067\:8a08\:7b97\:3059\:308b\:3088\:3046\:306b\
\:8a2d\:5b9a\:3057\:307e\:3059\:ff0e\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(Needs["\<PDEPlot`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Developer`SetSystemOptions["\<CatchMachineUnderflow\>" \[Rule] 
          False];\)\)}], "Input",
  CellLabel->"In[71]:="],

Cell["\<\
The KdV equation makes an notable example because it has nontrivial wave \
dynamics.\
\>", "Text"],

Cell["\<\
\:81ea\:660e\:3067\:306a\:3044\:6ce2\:52d5\:306e\:6319\:52d5\:3092\:793a\:3059\
 KdV \:65b9\:7a0b\:5f0f\:306f\:6700\:3082\:9069\:3057\:305f\:4f8b\:3067\:3059\
\:ff0e\
\>", "Text"],

Cell["\<\
This shows the breakdown of an initial pulse into a wavetrain of solitons.\
\>", "MathCaption"],

Cell["\:5358\:4e00\:521d\:671f\:30d1\:30eb\:30b9\:304c\:6ce2\:675f\:5217\:306b\
\:5206\:96e2\:3057\:3066\:3044\:304f\:69d8\:5b50\:3092\:793a\:3057\:307e\:3059\
\:ff0e", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L\  = \ 25; 
    sol\  = \ NDSolvePlot[{D[u[t, x], t]\  + \ 
              6\ u[t, x]\ D[u[t, x], x]\  + \ 
              D[u[t, x], \ x, x, \ x]\  \[Equal] \ 0, \ 
          u[0, x]\  \[Equal] \ Exp[\(-x^2\)], \ 
          u[t, \ \(-L\)]\  \[Equal] \ u[t, L]}, \ 
        u, \ {t, \ 0,  .5}, {x, \(-L\), L}, \[IndentingNewLine]\ 
        Frames \[Rule] 100, \ 
        PlotRange \[Rule] {{\(-L\), L}, {\(-1\), 1}}]\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"u", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 0.5`}, {"...", \(-25.`\), 
                  25.`, "..."}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[73]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[TextData[{
  "The NDSolvePlot program works by using a function ",
  StyleBox["NDSolve`ProcessEquations", "MR"],
  " which gives an ",
  StyleBox["NDSolve`StateData", "MR"],
  " object containing all of the information needed to compute the solution \
of the PDE.  Using the command ",
  StyleBox["NDSolve`Iterate", "MR"],
  ", the program advances the solution to times at regular intervals and \
plots the solution before continuing further."
}], "Text"],

Cell[TextData[{
  "NDSolvePlot \:30d7\:30ed\:30b0\:30e9\:30e0\:306f\:95a2\:6570 ",
  StyleBox["NDSolve`ProcessEquations", "MR"],
  " \:3092\:4f7f\:3063\:3066\:6a5f\:80fd\:3057\:307e\:3059\:ff0e\:3053\:308c\
\:306f\:ff0c\:504f\:5fae\:5206\:65b9\:7a0b\:5f0f\:306e\:89e3\:3092\:6c42\:3081\
\:308b\:306e\:306b\:5fc5\:8981\:306a\:3059\:3079\:3066\:306e\:60c5\:5831\:3092\
\:3082\:3064  ",
  StyleBox["NDSolve`StateData", "MR"],
  " \:30aa\:30d6\:30b8\:30a7\:30af\:30c8\:3092\:4e0e\:3048\:307e\:3059\:ff0e\
\:30b3\:30de\:30f3\:30c9 ",
  StyleBox["NDSolve`Iterate", "MR"],
  ", \:3092\:4f7f\:3063\:3066\:ff0c\:3053\:306e\:30d7\:30ed\:30b0\:30e9\:30e0\
\:306f\:4e00\:5b9a\:306e\:6642\:9593\:9593\:9694\:3067\:89e3\:3092\:ff11\:30b9\
\:30c6\:30c3\:30d7\:9032\:3081\:ff0c\:56f3\:3092\:63cf\:3044\:3066\:304b\:3089\
\:6b21\:306e\:30b9\:30c6\:30c3\:30d7\:3078\:9032\:307f\:307e\:3059\:ff0e"
}], "Text"],

Cell["\<\
It would be possible to take the computation further, but it is clear from \
the plot that the solution is being computed relatively slowly.  That is \
because the default error tolerances in NDSolve require nearly 1000 spatial \
points, so it is effectively solving a system of 1000 ODEs.  Because of the \
vector capabilities of NDSolve, it has been possible to implement a greater \
variety of methods, such as periodic pseudospectral methods, which \
effectively use a trigonometric instead of a polynomial approximation for \
derivatives and are very accurate.  They are also fast to compute since they \
can be found through FFTs.\
\>", "Text"],

Cell["\<\
\:8a08\:7b97\:3092\:3055\:3089\:306b\:9032\:3081\:308b\:3053\:3068\:306f\:53ef\
\:80fd\:3067\:3059\:304c\:ff0c\:56f3\:304b\:3089\:89e3\:306e\:8a08\:7b97\:306b\
\:306f\:6642\:9593\:304c\:304b\:304b\:308b\:3053\:3068\:304c\:308f\:304b\:308a\
\:307e\:3059\:ff0e\:305d\:308c\:306f\:ff0c\:8a31\:5bb9\:8aa4\:5dee\:306e\:30c7\
\:30d5\:30a9\:30eb\:30c8\:8a2d\:5b9a\:3067\:306f NDSolve \:306f 1000 \:500b\
\:307b\:3069\:306e\:70b9\:3092\:5fc5\:8981\:3068\:3057\:ff0c\:3057\:305f\:304c\
\:3063\:3066\:5b9f\:8cea\:7684\:306b 1000 \
\:500b\:306e\:9023\:7acb\:5e38\:5fae\:5206\:65b9\:7a0b\:5f0f\:3092\:89e3\:304f\
\:3053\:3068\:306b\:306a\:308b\:304b\:3089\:3067\:3059\:ff0e NDSolve \:306e\
\:30d9\:30af\:30c8\:30eb\:8868\:73fe\:306b\:3088\:308a\:ff0c\:3082\:3063\:3068\
\:591a\:304f\:306e\:89e3\:6cd5\:3092\:30a4\:30f3\:30d7\:30ea\:30e1\:30f3\:30c8\
\:3059\:308b\:3053\:3068\:304c\:3067\:304d\:308b\:3088\:3046\:306b\:306a\:308a\
\:307e\:3057\:305f\:ff0e\:305f\:3068\:3048\:3070\:ff0c\:5468\:671f\:64ec\:30b9\
\:30da\:30af\:30c8\:30eb\:6cd5\:3067\:306f\:ff0c\:5c0e\:95a2\:6570\:306b\:5b9f\
\:8cea\:7684\:306b\:306f\:591a\:9805\:5f0f\:3067\:306a\:304f\:4e09\:89d2\:95a2\
\:6570\:8fd1\:4f3c\:3092\:7528\:3044\:307e\:3059\:304c\:ff0c\:305d\:306e\:7d50\
\:679c\:6975\:3081\:3066\:9ad8\:3044\:7cbe\:5ea6\:304c\:5f97\:3089\:308c\:307e\
\:3059\:ff0e\:307e\:305f\:ff0c FFT \:3092\:4f7f\:3046\:306e\:3067\:ff0c\:9ad8\
\:901f\:3067\:3082\:3042\:308a\:307e\:3059\:ff0e\
\>", "Text"],

Cell["This shows the same thing on a  wider computational domain.", \
"MathCaption"],

Cell["\:540c\:3058\:8a08\:7b97\:3092\:3082\:3063\:3068\:5e83\:3044\:7bc4\:56f2\
\:306b\:3064\:3044\:3066\:884c\:3044\:307e\:3059\:ff0e", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L\  = \ 50; 
    sol\  = \ NDSolvePlot[{D[u[t, x], t]\  + \ 
              6\ u[t, x]\ D[u[t, x], x]\  + \ 
              D[u[t, x], \ x, x, \ x]\  \[Equal] \ 0, \ 
          u[0, x]\  \[Equal] \ Exp[\(-x^2\)], \ 
          u[t, \ \(-L\)]\  \[Equal] \ u[t, L]}, \ 
        u, \ {t, \ 0, 3}, {x, \(-L\), L}, 
        Method \[Rule] {"\<MethodOfLines\>", \ "\<SpatialDiscretization\>" \
\[Rule] {"\<TensorProductGrid\>", \ 
                DifferenceOrder -> "\<Pseudospectral\>"}}, \
\[IndentingNewLine]\ Frames \[Rule] 100, \ 
        PlotRange \[Rule] {{\(-L\), L}, {\(-1\), 1}}]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"u", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 3.`}, {"...", \(-50.`\), 
                  50.`, "..."}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[74]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[TextData[{
  StyleBox["NDSolve", "MR"],
  " also now has the ability to solve index 1 systems of \
differential-algebraic equations (DAEs).  Just as with ODEs and PDEs, all you \
have to do is put in the equations and NDSolve figures out when it needs to \
use the DAE solver."
}], "Text"],

Cell[TextData[{
  StyleBox["NDSolve", "MR"],
  " \:306f\:307e\:305f\:30a4\:30f3\:30c7\:30c3\:30af\:30b9\:ff11\:306e\:5fae\
\:5206\:4ee3\:6570\:65b9\:7a0b\:5f0f differential-algebraic equations (DAEs) \
\:3092\:89e3\:304f\:3053\:3068\:3082\:3067\:304d\:307e\:3059\:ff0e\:5e38\:5fae\
\:5206\:65b9\:7a0b\:5f0f\:3084\:504f\:5fae\:5206\:65b9\:7a0b\:5f0f\:3068\:540c\
\:69d8\:ff0c\:30e6\:30fc\:30b6\:30fc\:306f\:305f\:3060\:65b9\:7a0b\:5f0f\:3092\
\:5165\:529b\:3059\:308c\:3070\:3088\:304f\:ff0c\:3059\:308b\:3068 NDSolve \
\:304c DAE \:30bd\:30eb\:30d0\:30fc\:304c\:5fc5\:8981\:304b\:3069\:3046\:304b\
\:3092\:5224\:65ad\:3057\:307e\:3059\:ff0e"
}], "Text"],

Cell["\<\
Here is an index 1 system of DAEs (due to Robertson) modelling chemical \
kinetics. The problem involves 2 DEs and a material balance equation.\
\>", "MathCaption"],

Cell["\<\
\:3053\:308c\:306f\:5316\:5b66\:53cd\:5fdc\:306e\:30e2\:30c7\:30eb\:306b\:4f7f\
\:308f\:308c\:308b Robertson \:306b\:3088\:308b\:30a4\:30f3\:30c7\:30c3\:30af\
\:30b9\:ff11\:306e DAE \:3067\:3059\:ff0e\:ff12\:3064\:306e\:5fae\:5206\:65b9\
\:7a0b\:5f0f\:3068\:ff11\:3064\:306e\:7269\:8cea\:30d0\:30e9\:30f3\:30b9\:306e\
\:5f0f\:304b\:3089\:306a\:3063\:3066\:3044\:307e\:3059\:ff0e\
\>", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DEs", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(x'\)[t] \[Equal] \(-x[t]\)/25 + 10\^4\ y[t]\ z[t]\)},
              {\(\(y'\)[t] \[Equal] 
                  x[t]/25 - 10^4\ y[t]\ z[t] - 3\ 10\^7\ y[t]\^2\)}
              }], ")"}]}], ";"}]], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(\(bal\  = \ x[t] + y[t] + z[t] \[Equal] 1;\)\)], "Input",
  CellLabel->"In[76]:="],

Cell["This solves the DAEs.", "MathCaption"],

Cell["\:3053\:306e DAE \:306e\:89e3\:3092\:6c42\:3081\:307e\:3059\:ff0e", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol\  = \ 
      First[NDSolve[{DEs, \ bal, \ x[0] \[Equal] 1, y[0] \[Equal] 0}, {x, y, 
            z}, {t, 0, 4\ 10\^4}]]\)], "Input",
  CellLabel->"In[77]:=",
  CellTags->{"b:1", "ndsg:0"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"x", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 40000.`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"y", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 40000.`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"z", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 40000.`}}, "<>"]\),
            False,
            Editable->False]}]}], "}"}]], "Output",
  CellLabel->"Out[77]="]
}, Open  ]],

Cell["\<\
When NDSolve detected the equation bal without any derivative terms, it \
recognized the system as being a DAE and used the appropriate solver which is \
based on the IDA package.\
\>", "Text"],

Cell["\<\
When NDSolve \:304c\:5c0e\:95a2\:6570\:3092\:542b\:307e\:306a\:3044\:65b9\
\:7a0b\:5f0f\:3092\:767a\:898b\:3059\:308b\:3068\:ff0c\:65b9\:7a0b\:5f0f\:7cfb\
\:306f DAE \:3067\:3042\:308b\:3053\:3068\:3092\:8a8d\:8b58\:3057\:ff0c IDA \
\:30d1\:30c3\:30b1\:30fc\:30b8\:306b\:57fa\:3065\:304f\:9069\:5207\:306a\:30bd\
\:30eb\:30d0\:30fc\:3092\:4f7f\:3044\:307e\:3059\:ff0e\
\>", "Text"],

Cell["\<\
This makes a plot showing how well the algebraic condition was satisfied.\
\>", "MathCaption",
  CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],

Cell["\:4ee3\:6570\:65b9\:7a0b\:5f0f\:304c\:3069\:3093\:306a\:7cbe\:5ea6\:3067\
\:6210\:308a\:7acb\:3063\:3066\:3044\:308b\:304b\:3092\:30d7\:30ed\:30c3\:30c8\
\:3057\:307e\:3059\:ff0e", "MathCaption",
  CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[x[t] + y[t] + z[t]\  - \ 1\  /. \ %], {t, 0, 40000}, \ 
        PlotRange \[Rule] All];\)\)], "Input",
  CellLabel->"In[78]:=",
  CellTags->{"b:1", "ndsg:0"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 2.38095e-005 0.35497 2.98836e+010 [
[.2619 .34247 -15 -9 ]
[.2619 .34247 15 0 ]
[.5 .34247 -15 -9 ]
[.5 .34247 15 0 ]
[.7381 .34247 -15 -9 ]
[.7381 .34247 15 0 ]
[.97619 .34247 -15 -9 ]
[.97619 .34247 15 0 ]
[.01131 .05613 -43.5 -6.25 ]
[.01131 .05613 0 6.25 ]
[.01131 .20555 -43.5 -6.25 ]
[.01131 .20555 0 6.25 ]
[.01131 .50439 -37.5 -6.25 ]
[.01131 .50439 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .35497 m
.2619 .36122 L
s
[(10000)] .2619 .34247 0 1 Mshowa
.5 .35497 m
.5 .36122 L
s
[(20000)] .5 .34247 0 1 Mshowa
.7381 .35497 m
.7381 .36122 L
s
[(30000)] .7381 .34247 0 1 Mshowa
.97619 .35497 m
.97619 .36122 L
s
[(40000)] .97619 .34247 0 1 Mshowa
.125 Mabswid
.07143 .35497 m
.07143 .35872 L
s
.11905 .35497 m
.11905 .35872 L
s
.16667 .35497 m
.16667 .35872 L
s
.21429 .35497 m
.21429 .35872 L
s
.30952 .35497 m
.30952 .35872 L
s
.35714 .35497 m
.35714 .35872 L
s
.40476 .35497 m
.40476 .35872 L
s
.45238 .35497 m
.45238 .35872 L
s
.54762 .35497 m
.54762 .35872 L
s
.59524 .35497 m
.59524 .35872 L
s
.64286 .35497 m
.64286 .35872 L
s
.69048 .35497 m
.69048 .35872 L
s
.78571 .35497 m
.78571 .35872 L
s
.83333 .35497 m
.83333 .35872 L
s
.88095 .35497 m
.88095 .35872 L
s
.92857 .35497 m
.92857 .35872 L
s
.25 Mabswid
0 .35497 m
1 .35497 L
s
.02381 .05613 m
.03006 .05613 L
s
gsave
.01131 .05613 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-11) show
grestore
.02381 .20555 m
.03006 .20555 L
s
gsave
.01131 .20555 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-12) show
grestore
.02381 .50439 m
.03006 .50439 L
s
gsave
.01131 .50439 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-12) show
grestore
.125 Mabswid
.02381 .08602 m
.02756 .08602 L
s
.02381 .1159 m
.02756 .1159 L
s
.02381 .14578 m
.02756 .14578 L
s
.02381 .17567 m
.02756 .17567 L
s
.02381 .23544 m
.02756 .23544 L
s
.02381 .26532 m
.02756 .26532 L
s
.02381 .2952 m
.02756 .2952 L
s
.02381 .32509 m
.02756 .32509 L
s
.02381 .38485 m
.02756 .38485 L
s
.02381 .41474 m
.02756 .41474 L
s
.02381 .44462 m
.02756 .44462 L
s
.02381 .4745 m
.02756 .4745 L
s
.02381 .02625 m
.02756 .02625 L
s
.02381 .53427 m
.02756 .53427 L
s
.02381 .56416 m
.02756 .56416 L
s
.02381 .59404 m
.02756 .59404 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .35498 m
.02846 .35496 L
.02952 .35497 L
.03068 .35497 L
.03178 .355 L
.03279 .35495 L
.03399 .35519 L
.03527 .35497 L
.03635 .35495 L
.03754 .35495 L
.0388 .35507 L
.03951 .35521 L
.04016 .35444 L
.04145 .35415 L
.04262 .35162 L
.04384 .35461 L
.04514 .35833 L
.04634 .35606 L
.04748 .35537 L
.04872 .35495 L
.05003 .35318 L
.05071 .35307 L
.05146 .3537 L
.05278 .34388 L
.05404 .34935 L
.05519 .4227 L
.05583 .33791 L
.05652 .35332 L
.05778 .35497 L
.05895 .35497 L
.0602 .35497 L
.06127 .35497 L
.06244 .35497 L
.06371 .35489 L
.06443 .35486 L
.0651 .35505 L
.06581 .35506 L
.06646 .35494 L
.0672 .3552 L
.0679 .3553 L
.06915 .35391 L
.0703 .35596 L
.07156 .35415 L
.0722 .35519 L
.0729 .35534 L
.07366 .35476 L
.07437 .35493 L
.07501 .35504 L
.07571 .35497 L
.07647 .35496 L
Mistroke
.07728 .35497 L
.07803 .35497 L
.07873 .35498 L
.07944 .35497 L
.0802 .35497 L
.08088 .35497 L
.08159 .35497 L
.08282 .35497 L
.08352 .35497 L
.08418 .35497 L
.08545 .35497 L
.08616 .35497 L
.08683 .35497 L
.08804 .35497 L
.08933 .35496 L
.09049 .35498 L
.09157 .35497 L
.09275 .35497 L
.09403 .35497 L
.09531 .35496 L
.09604 .35497 L
.09671 .35497 L
.09743 .35498 L
.09808 .35497 L
.09883 .35496 L
.09954 .35497 L
.1008 .35498 L
.10196 .35495 L
.10323 .35497 L
.10387 .35499 L
.10458 .35497 L
.10579 .35495 L
.10708 .35487 L
.10776 .35498 L
.1085 .35508 L
.10981 .35498 L
.11104 .35494 L
.11173 .35496 L
.11237 .35497 L
.11354 .35497 L
.11477 .35497 L
.11588 .35497 L
.11707 .35497 L
.11819 .35497 L
.11921 .35497 L
.12041 .35497 L
.12171 .35497 L
.12293 .35497 L
.12407 .35496 L
.12527 .35497 L
Mistroke
.12656 .35498 L
.12778 .35497 L
.1289 .35497 L
.1302 .35497 L
.13094 .35497 L
.13162 .35497 L
.13288 .35497 L
.13358 .35497 L
.13422 .35497 L
.13551 .35497 L
.13616 .35497 L
.13688 .35497 L
.13765 .35497 L
.13838 .35497 L
.13904 .35497 L
.13976 .35497 L
.14043 .35497 L
.14116 .35497 L
.1418 .35498 L
.14248 .35498 L
.14378 .35498 L
.14497 .35496 L
.14611 .35496 L
.14736 .35497 L
.14866 .35497 L
.14987 .35498 L
.151 .35497 L
.15204 .35497 L
.15323 .35496 L
.15435 .35496 L
.15558 .35496 L
.15688 .35497 L
.15798 .35497 L
.1592 .35497 L
.16051 .35497 L
.16125 .35497 L
.16192 .35498 L
.16322 .35497 L
.16446 .35497 L
.16561 .35496 L
.16666 .35496 L
.16786 .35497 L
.169 .35497 L
.17006 .35497 L
.17105 .35497 L
.17208 .35498 L
.17321 .35498 L
.17436 .35498 L
.1756 .35497 L
.17675 .35496 L
Mistroke
.17779 .35496 L
.17901 .35496 L
.1797 .35496 L
.18034 .35496 L
.1815 .35496 L
.18274 .35497 L
.18395 .35498 L
.18526 .35499 L
.1865 .35498 L
.18765 .35496 L
.18879 .35496 L
.18983 .35496 L
.19096 .35495 L
.19215 .35495 L
.19345 .35496 L
.19465 .35498 L
.19594 .355 L
.19667 .355 L
.19736 .355 L
.1986 .35498 L
.19973 .35497 L
.20103 .35496 L
.20227 .35495 L
.20332 .35494 L
.20447 .35494 L
.20568 .35496 L
.20682 .35499 L
.20788 .35501 L
.20885 .35501 L
.20991 .35499 L
.21103 .35498 L
.21217 .35497 L
.21339 .35495 L
.21444 .35492 L
.21558 .35491 L
.21628 .35492 L
.21693 .35493 L
.21819 .35499 L
.21935 .35501 L
.22057 .35502 L
.22177 .35501 L
.22309 .355 L
.22434 .35498 L
.22549 .35493 L
.22664 .35489 L
.22767 .35489 L
.22887 .35494 L
.23 .35499 L
.23123 .35502 L
.23253 .35503 L
Mistroke
.23366 .35504 L
.23487 .35505 L
.23617 .355 L
.23738 .35489 L
.23812 .35485 L
.23882 .35484 L
.24013 .35488 L
.24118 .35495 L
.24234 .35499 L
.24347 .35502 L
.24469 .35508 L
.24583 .35511 L
.24686 .3551 L
.24786 .35501 L
.2489 .35487 L
.25005 .35479 L
.25127 .35481 L
.25242 .35487 L
.25346 .35477 L
.25461 .35453 L
.25583 .35425 L
.25654 .35414 L
.25718 .3541 L
.25844 .3543 L
.25963 .35495 L
.26093 .35573 L
.26216 .35605 L
.2633 .35608 L
.26448 .35589 L
.26579 .35551 L
.26717 .35503 L
.26844 .35468 L
.26955 .35456 L
.27073 .35457 L
.2719 .35468 L
.27319 .35484 L
.27431 .35497 L
.2755 .35506 L
.27663 .3551 L
.27765 .35511 L
.27894 .35511 L
.28014 .35512 L
.2814 .35515 L
.28211 .35516 L
.28278 .35518 L
.28351 .35519 L
.28418 .35519 L
.2849 .35519 L
.28568 .35517 L
.28635 .35514 L
Mistroke
.28707 .35509 L
.28835 .35495 L
.28966 .35483 L
.2904 .35479 L
.29108 .35476 L
.29233 .35474 L
.29365 .35476 L
.29484 .35483 L
.29595 .35489 L
.29716 .35494 L
.29846 .35497 L
.29978 .355 L
.30103 .35505 L
.30232 .35513 L
.30302 .35517 L
.30375 .35521 L
.30498 .35525 L
.3061 .35524 L
.30731 .35518 L
.308 .35511 L
.30864 .35503 L
.30933 .35492 L
.31008 .35483 L
.31079 .35476 L
.31144 .35471 L
.31268 .35467 L
.31399 .35468 L
.31467 .35471 L
.3154 .35475 L
.31671 .35483 L
.31752 .35486 L
.31828 .35488 L
.31901 .3549 L
.31971 .35492 L
.32098 .35498 L
.32213 .35507 L
.32347 .35523 L
.3247 .35533 L
.32579 .35538 L
.32693 .35538 L
.32808 .35529 L
.32934 .3551 L
.32998 .35497 L
.33068 .35485 L
.33196 .3547 L
.33272 .35465 L
.33343 .35462 L
.33408 .35461 L
.33477 .35462 L
.33601 .35466 L
Mistroke
.33718 .35472 L
.33845 .35475 L
.33916 .35477 L
.33983 .35479 L
.34047 .35481 L
.34116 .35485 L
.34236 .35497 L
.34305 .35508 L
.34377 .35522 L
.34506 .35543 L
.34626 .35554 L
.34738 .35556 L
.34861 .35548 L
.34992 .35524 L
.35061 .35506 L
.35134 .3549 L
.35214 .35477 L
.35288 .35468 L
.35357 .35462 L
.35421 .35459 L
.35492 .35457 L
.35569 .35457 L
.35632 .35458 L
.35702 .35459 L
.35775 .35459 L
.35843 .35459 L
.35965 .35458 L
.36095 .35461 L
.3616 .35465 L
.3623 .35472 L
.36354 .35496 L
.36424 .35517 L
.36499 .35538 L
.36571 .35555 L
.36636 .35566 L
.3676 .35578 L
.36879 .35575 L
.37007 .35555 L
.37079 .35536 L
.37147 .35514 L
.37272 .35485 L
.3739 .35468 L
.37495 .3546 L
.3761 .35454 L
.37848 .35443 L
.3797 .35435 L
.38039 .35432 L
.38103 .35431 L
.38167 .35433 L
.38235 .35438 L
Mistroke
.38361 .35462 L
.38472 .35502 L
.38595 .35553 L
.3871 .35585 L
.38833 .35602 L
.38949 .35601 L
.39055 .35585 L
.39181 .35546 L
.39298 .35529 L
.39426 .35563 L
.39498 .356 L
.39564 .35642 L
.39699 .3574 L
.39842 .35844 L
.39965 .35914 L
.40034 .3594 L
.40099 .35952 L
.4023 .35931 L
.4035 .35846 L
.40416 .35767 L
.40488 .35649 L
.40619 .3537 L
.40693 .35242 L
.40761 .35151 L
.4084 .35076 L
.40912 .35034 L
.41042 .35012 L
.41116 .35025 L
.41183 .35052 L
.41306 .35125 L
.41421 .35214 L
.41557 .35331 L
.41681 .35434 L
.41803 .35518 L
.41935 .35583 L
.42007 .35608 L
.42074 .35625 L
.42206 .35642 L
.42331 .35643 L
.42449 .35631 L
.42556 .35612 L
.42672 .35585 L
.42914 .35517 L
.43047 .35478 L
.43173 .35448 L
.43291 .35427 L
.43419 .35412 L
.43535 .35404 L
.43642 .35401 L
.43743 .354 L
Mistroke
.43854 .35402 L
.4397 .35406 L
.44078 .35411 L
.44197 .35416 L
.44323 .35422 L
.44389 .35424 L
.44461 .35425 L
.44589 .35428 L
.4471 .35432 L
.44839 .35436 L
.44961 .35443 L
.45074 .35453 L
.45203 .35467 L
.45277 .35478 L
.45346 .3549 L
.45632 .35554 L
.45758 .35578 L
.45878 .35596 L
.45944 .35603 L
.46016 .3561 L
.46141 .35615 L
.46264 .35614 L
.46376 .35606 L
.46506 .3559 L
.4663 .35566 L
.46851 .35508 L
.46973 .35483 L
.47087 .35464 L
.47152 .35455 L
.47223 .35447 L
.47345 .35437 L
.4747 .35429 L
.47585 .35425 L
.47711 .35422 L
.47783 .35421 L
.47849 .3542 L
.47983 .35418 L
.48058 .35417 L
.48128 .35415 L
.48261 .35411 L
.48333 .35409 L
.48401 .35408 L
.48524 .35408 L
.48589 .3541 L
.4866 .35413 L
.48783 .35424 L
.48913 .35443 L
.49023 .35467 L
.49144 .35504 L
.49285 .35555 L
Mistroke
.49417 .35597 L
.4949 .35616 L
.4957 .35633 L
.49636 .35645 L
.49708 .35656 L
.49777 .35662 L
.49841 .35666 L
.49908 .35667 L
.49981 .35665 L
.50112 .35653 L
.50232 .35632 L
.50461 .35563 L
.50582 .35526 L
.50708 .35496 L
.5082 .35475 L
.50942 .35458 L
.51156 .35437 L
.51622 .35395 L
.51761 .35375 L
.51892 .35357 L
.5201 .35344 L
.52138 .35334 L
.52206 .35332 L
.52278 .35332 L
.52408 .3534 L
.52478 .3535 L
.52545 .35363 L
.52618 .35381 L
.52696 .35406 L
.52835 .35467 L
.52967 .35542 L
.53087 .35603 L
.53215 .35654 L
.53345 .35693 L
.53463 .35715 L
.53581 .35727 L
.53692 .35727 L
.53823 .35715 L
.53943 .35691 L
.54074 .35651 L
.54213 .35598 L
.54335 .35561 L
.54468 .3553 L
.54593 .35509 L
.54709 .35492 L
.55161 .35421 L
.55394 .35352 L
.55516 .35309 L
.55645 .35271 L
.55713 .35254 L
Mistroke
.55788 .35239 L
.5592 .35224 L
.55984 .35221 L
.56054 .35224 L
.56178 .35241 L
.56293 .35275 L
.56418 .35332 L
.56535 .35408 L
.56644 .35498 L
.5685 .35643 L
.56953 .35697 L
.57067 .35742 L
.5719 .35774 L
.57303 .3579 L
.57432 .35793 L
.57555 .3578 L
.57669 .35757 L
.57774 .35726 L
.58012 .35647 L
.59896 .3509 L
.60024 .35144 L
.60144 .35226 L
.6021 .35285 L
.60283 .35361 L
.60409 .35492 L
.60529 .35553 L
.60657 .35557 L
.60766 .35517 L
.60887 .35435 L
.61011 .35317 L
.61144 .35164 L
.61385 .34854 L
.61646 .34537 L
.61718 .34464 L
.61794 .34398 L
.6186 .3435 L
.61931 .34312 L
.62012 .34286 L
.62088 .34282 L
.62163 .34298 L
.62231 .34332 L
.62297 .34385 L
.62369 .34466 L
.62445 .34579 L
.62516 .34713 L
.6265 .35049 L
.62773 .35457 L
.62843 .35707 L
.62917 .35927 L
.62986 .36092 L
Mistroke
.6305 .36214 L
.6317 .36366 L
.63234 .36409 L
.63303 .36431 L
.63373 .36428 L
.63446 .36401 L
.63578 .363 L
.63701 .36157 L
.63817 .35995 L
.64078 .35588 L
.64204 .35403 L
.6427 .35316 L
.64341 .35235 L
.6447 .35123 L
.64589 .35076 L
.64703 .35094 L
.6481 .3514 L
.65054 .35218 L
.65311 .35286 L
.65556 .35363 L
.65691 .3542 L
.65838 .355 L
.65972 .35594 L
.66096 .35703 L
.66605 .36442 L
.66873 .36941 L
.67019 .37163 L
.67155 .37334 L
.67284 .37464 L
.67403 .37554 L
.67534 .37621 L
.67606 .37642 L
.67674 .37652 L
.67793 .37645 L
.67903 .3761 L
.68023 .37539 L
.68151 .37427 L
.68266 .37292 L
.68371 .37139 L
.68608 .36697 L
.69037 .35974 L
.70013 .34593 L
.70488 .33665 L
.70749 .33117 L
.70877 .32892 L
.70995 .32718 L
.71107 .32587 L
.71225 .3249 L
.71343 .32438 L
.71473 .32442 L
Mistroke
.71582 .32498 L
.71698 .32615 L
.71808 .32785 L
.71908 .32994 L
.72036 .33339 L
.72172 .3381 L
.72417 .34948 L
.72702 .36287 L
.72971 .37296 L
.7322 .38035 L
.7345 .38562 L
.73704 .38994 L
.73838 .39161 L
.73979 .39298 L
.74102 .39386 L
.74171 .39424 L
.74235 .39452 L
.74477 .39526 L
.74591 .39559 L
.74697 .39578 L
.74809 .39577 L
.74931 .3954 L
.75062 .39444 L
.75187 .39287 L
.75299 .39079 L
.75421 .38769 L
.75554 .38321 L
.75695 .37698 L
.75949 .36138 L
.76187 .3408 L
.76445 .31584 L
.76563 .30633 L
.76688 .29774 L
.76796 .29157 L
.76912 .28629 L
.77024 .28251 L
.77127 .28026 L
.7723 .27919 L
.77328 .2793 L
.77442 .28084 L
.77547 .28364 L
.77662 .28827 L
.77785 .29504 L
.78282 .34293 L
.78524 .3745 L
.78744 .39776 L
.78977 .41702 L
.79227 .4323 L
.79357 .43841 L
.79498 .44377 L
Mistroke
.7963 .44774 L
.79754 .45067 L
.79868 .45277 L
.79972 .45429 L
.80087 .45561 L
.80211 .45668 L
.80442 .45812 L
.80564 .4589 L
.80694 .45984 L
.80815 .46058 L
.80924 .46094 L
.81035 .46081 L
.81138 .46007 L
.81244 .45857 L
.81341 .45637 L
.81448 .45291 L
.8156 .4479 L
.81681 .44076 L
.81791 .43246 L
.81909 .42143 L
.82038 .4067 L
.82267 .37258 L
.82483 .32975 L
.82715 .27577 L
.82964 .22671 L
.83107 .20388 L
.83238 .1865 L
.83363 .17318 L
.83495 .16274 L
.83625 .15612 L
.83746 .15341 L
.83816 .15339 L
.83879 .15435 L
.83952 .15666 L
.84021 .16002 L
.84089 .16448 L
.8416 .17044 L
.84289 .18442 L
.84427 .20428 L
.84579 .23203 L
.85059 .32697 L
.8533 .36484 L
.85581 .39258 L
.86104 .43988 L
.866 .48996 L
.8683 .52083 L
.87079 .55455 L
.87193 .56821 L
.87314 .58075 L
.87418 .58973 L
Mistroke
.87529 .59706 L
.87648 .60192 L
.87759 .60332 L
.87891 .60054 L
.88011 .59337 L
.88142 .5799 L
.88216 .5695 L
.88284 .558 L
.88418 .52992 L
.88543 .49646 L
.88792 .40708 L
.89066 .2837 L
.89333 .18953 L
.89483 .15052 L
.89549 .13656 L
.8962 .12365 L
.89749 .10609 L
.8987 .09641 L
.89989 .0934 L
.90097 .09624 L
.90215 .10543 L
.90345 .12285 L
.9041 .13455 L
.9048 .14927 L
.90606 .18154 L
.91044 .35089 L
.91275 .44121 L
.91392 .47563 L
.9152 .5053 L
.91592 .5182 L
.9167 .52924 L
.91743 .53701 L
.9181 .54193 L
.9194 .54562 L
.92006 .54464 L
.92077 .54146 L
.9221 .53003 L
.92284 .5206 L
.92351 .51021 L
.92605 .45611 L
.92832 .38959 L
.93076 .31226 L
.93216 .27987 L
.93343 .25736 L
.93472 .24037 L
.93593 .22843 L
.93714 .21965 L
.93826 .21339 L
.94079 .20183 L
.94207 .1952 L
Mistroke
.94328 .18712 L
.94467 .17433 L
.94593 .1584 L
.95041 .06964 L
.9515 .05125 L
.95266 .03527 L
.95394 .02265 L
.95513 .01605 L
.95581 .01472 L
.95654 .01534 L
.95723 .01801 L
.95786 .02236 L
.95907 .03581 L
.96035 .058 L
.96153 .08615 L
.96263 .11967 L
.96514 .22392 L
.96641 .29286 L
.96709 .33391 L
.9678 .37361 L
.96912 .41527 L
.97034 .42552 L
.97113 .42154 L
.97187 .41251 L
.97254 .40161 L
.97326 .38843 L
.97394 .37625 L
.97466 .36513 L
.97594 .35487 L
.97619 .35497 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{1, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00;P3oool0
0`000000oooo0?ooo`3_0?ooo`00;P3oool00`000000oooo0?ooo`3_0?ooo`00;P3oool00`000000
oooo0?ooo`3_0?ooo`00;P3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo0180oooo
000^0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool04P3oool002h0oooo00<00000
0?ooo`3oool0f@3oool2000001@0oooo000^0?ooo`800000fP3oool2000001@0oooo000^0?ooo`03
0000003oool0oooo0=T0oooo0P00000D0?ooo`00;P3oool00`000000oooo0?ooo`3I0?ooo`800000
503oool002h0oooo00<000000?ooo`3oool0f@3oool2000001@0oooo00070?ooo`D0000000@0oooo
0000003oool0oooo1@0000020?ooo`8000005@3oool00`000000oooo0?ooo`3I0?ooo`800000503o
ool000T0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00@0
00000?ooo`3oool00000503oool00`000000oooo0?ooo`3I0?ooo`800000503oool000T0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000001@0
oooo00<000000?ooo`3oool0f@3oool00`000000oooo0000000C0?ooo`0000<0oooo000000000000
0P0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`04
0000003oool0oooo000001@0oooo0P00003J0?ooo`030000003oool0000001<0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00@000000?ooo`3oool00000503oool0
0`000000oooo0?ooo`3H0?ooo`040000003oool0oooo000001<0oooo00080?ooo`8000001`3oool2
000000@0oooo0P0000080?ooo`<000000P3oool3000000D0oooo00<000000?ooo`3oool0f03oool0
10000000oooo0?ooo`00000C0?ooo`008P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0f03oool010000000oooo0?ooo`00000C0?ooo`00703oool3
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0=P0oooo00@000000?ooo`3oool000004`3oool00280oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0=P0oooo00@000000?ooo`3oool000004`3o
ool00240oooo0P0000030?ooo`8000001P3oool00`000000oooo0?ooo`3H0?ooo`040000003oool0
oooo000001<0oooo000^0?ooo`800000f@3oool010000000oooo0?ooo`00000C0?ooo`00;P3oool0
0`000000oooo0?ooo`3H0?ooo`040000003oool0oooo000001<0oooo000^0?ooo`030000003oool0
oooo0<`0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000C0?ooo`00;P3oool0
0`000000oooo0?ooo`3<0?ooo`8000002P3oool010000000oooo0?ooo`00000C0?ooo`00;P3oool0
0`000000oooo0?ooo`3<0?ooo`8000002P3oool010000000oooo0?ooo`00000C0?ooo`00;P3oool0
0`000000oooo0?ooo`3<0?ooo`8000002P3oool010000000oooo0?ooo`00000C0?ooo`00;P3oool0
0`000000oooo0?ooo`3<0?ooo`8000002P3oool010000000oooo0?ooo`00000C0?ooo`00;P3oool2
00000<d0oooo0P0000090?ooo`050000003oool0oooo0?ooo`0000004`3oool002h0oooo00<00000
0?ooo`3oool0c03oool2000000T0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`00;P3oool0
0`000000oooo0?ooo`3<0?ooo`8000002@3oool01@000000oooo0?ooo`3oool0000001<0oooo000^
0?ooo`030000003oool0oooo0<`0oooo0P0000090?ooo`050000003oool0oooo0?ooo`0000004`3o
ool002h0oooo00<000000?ooo`3oool0b`3oool00`000000oooo000000090?ooo`050000003oool0
oooo0?ooo`0000004`3oool002h0oooo00<000000?ooo`3oool0b`3oool00`000000oooo00000009
0?ooo`050000003oool0oooo0?ooo`0000004`3oool002h0oooo00<000000?ooo`3oool0b`3oool0
0`000000oooo000000090?ooo`050000003oool0oooo0?ooo`0000004`3oool002h0oooo0P00003<
0?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`00;P3o
ool00`000000oooo0?ooo`3;0?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool0
oooo0000000C0?ooo`00;P3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool00000203oool01@000000oooo0?ooo`3oool0000001<0oooo000^0?ooo`03
0000003oool0oooo0;d0oooo0P00000<0?ooo`040000003oool0oooo000000P0oooo00D000000?oo
o`3oool0oooo0000000C0?ooo`00;P3oool00`000000oooo0?ooo`2m0?ooo`800000303oool01000
0000oooo0?ooo`0000080?ooo`050000003oool0oooo0?ooo`0000004`3oool002h0oooo00<00000
0?ooo`3oool0_@3oool2000000`0oooo00@000000?ooo`3oool00000203oool01@000000oooo0?oo
o`3oool0000001<0oooo000^0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`0000002`3o
ool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0?ooo`0000004`3oool002h0oooo
0P00002n0?ooo`030000003oool0000000/0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo000^0?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`0000002`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool002h0oooo00<000000?ooo`3oool0_03oool010000000oooo
0?ooo`00000;0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`00;P3oool00`000000oooo0?ooo`2l0?ooo`040000003oool0oooo0000
00/0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00080?ooo`8000000`3oool00`000000oooo0?ooo`0500000080oooo0P00000E0?oo
o`030000003oool0oooo0;`0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`00
00070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool000L0oooo00@00000
0?ooo`3oool000000`3oool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
0000503oool00`000000oooo0?ooo`2l0?ooo`040000003oool0oooo000000/0oooo00@000000?oo
o`3oool000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000:0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00
000D0?ooo`030000003oool0oooo0;`0oooo00@000000?ooo`3oool000002`3oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool000030?oo
o`0000000000008000000`3oool2000000@0oooo00D000000?ooo`000000oooo000000030?ooo`04
0000003oool0oooo000001@0oooo00<000000?ooo`3oool0_03oool010000000oooo0?ooo`00000;
0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0@0?ooo`00203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000`3o
ool010000000oooo0?ooo`00000D0?ooo`800000_@3oool010000000oooo0?ooo`00000;0?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?oo
o`00203oool3000000H0oooo0P0000040?ooo`8000005@3oool00`000000oooo0?ooo`2l0?ooo`04
0000003oool0oooo000000/0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0100oooo000Q0?ooo`<000000P3oool3000000D0oooo00<000000?oo
o`3oool0_03oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`008P3oool010000000oooo0?ooo`3o
ool2000000H0oooo00<000000?ooo`3oool0_03oool01@000000oooo0?ooo`3oool0000000X0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100
oooo000L0?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0_03oool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2l0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0403oool00240oooo0P0000030?ooo`<000001@3oool00`00
0000oooo0?ooo`2l0?ooo`050000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool002h0oooo0P00002m
0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`00;P3oool00`000000oooo0?oo
o`2l0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`00;P3oool00`000000oooo
0?ooo`2l0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`00;P3oool00`000000
oooo0?ooo`2l0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`00;P3oool00`00
0000oooo0?ooo`2k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@
0?ooo`00;P3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0@0?ooo`00;P3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`00;P3oool200000;`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo000^0?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0100oooo000^0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0100oooo000^0?ooo`030000003oool0oooo0:h0oooo
0P00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0@0?ooo`00;P3oool00`000000oooo0?ooo`2^0?ooo`8000002`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool002h0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`00;P3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0100oooo000^0?ooo`800000[P3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?oo
o`00;P3oool00`000000oooo0?ooo`2]0?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo000^0?ooo`03
0000003oool0oooo0:d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool002h0oooo00<000000?ooo`3o
ool09`3oool500000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000N0?ooo`@0
00000`3oool2000000@0oooo0P0000040?ooo`800000103oool2000001h0oooo0P0000040?ooo`80
0000103oool2000000@0oooo0`0000020?ooo`<00000203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool30000
0080oooo0P0000020?ooo`040000003oool00000000000@0oooo0P0000040?ooo`8000000`3oool0
02h0oooo00<000000?ooo`3oool0:@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000001`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`00000000000P3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0000000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool100000040oooo0@3oool002h0oooo00<000000?ooo`3oool0:@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000001h0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00D000000?ooo`3oool000000?ooo`0200000080oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo00000004000000060?ooo`000000oooo0?ooo`00
0000oooo0P0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool100000040oooo0@3oool002h0oooo00<000000?ooo`3oool0:@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool07@3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool07@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00D000000?ooo`3oool000000?ooo`0200000080oooo0P00
00000`3oool000000?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0000000000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool100000040oooo0@3oool002h0oooo0P00000Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0K0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000703oool010000000oooo0?ooo`0000020?oo
o`@000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0000000000080oooo0P00
00000`3oool000000?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000P3oool01@000000
oooo0?ooo`000000oooo008000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo0@0000010?ooo`40oooo000^0?ooo`030000003oool0oooo02P0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000007`3oool2000000@0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P00000N0?ooo`800000103oool2000000040?ooo`000000
oooo0?ooo`800000103oool2000000@0oooo0P0000080?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000
0`3oool200000080oooo00@000000?ooo`0000000000103oool2000000@0oooo0P0000030?ooo`00
;P3oool00`000000oooo0?ooo`2N0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0100oooo000^0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0UP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0@0?ooo`00;P3oool00`000000oooo0?ooo`040?ooo`800000
P`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0403oool002h0oooo00<000000?ooo`3oool0103o
ool2000008<0oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`00;P3oool0
1P000000oooo0?ooo`3oool000000?ooo`<00000DP3oool200000240oooo0`0000060?ooo`<00000
00<0oooo0000003oool00P3oool010000000oooo0?ooo`3oool3000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0403oool002P0
ooookP00000:0?ooo`00;P3oool00`000000oooo0?ooo`020?ooo`040000003oool0000000000080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool2000000X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000T0oooo0`00000?0?ooo`00;P3o
ool00`000000oooo0?ooo`040?ooo`800000Q`3oool2000000H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool200000100oooo
000^0?ooo`030000003oool0oooo00@0oooo0P00002@0?ooo`050000003oool0oooo0?ooo`000000
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000T0oooo0P00000@0?ooo`00;P3oool00`000000oooo
0?ooo`040?ooo`800000T03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000002@3oool200000100oooo000^0?ooo`030000003oool0oooo00@0oooo0P00002A0?ooo`80
00002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo0P00000@0?ooo`00;P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?oo
o`800000403oool002h0oooo0P0000050?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000090?ooo`800000403oool002h0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2O0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000002@3oool200000100oooo000^0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0W`3oool4000000P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo0P00000@0?ooo`00;P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0:40oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000002@3oool200000100oooo000^0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000002@3oool200000100oooo000^0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0Z`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool2
00000100oooo000^0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Z`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0?
0?ooo`00;P3oool2000000D0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0?0?ooo`00;P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool03`3oool002h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo00l0oooo000^0?ooo`030000003oool0oooo
0;<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00000
0?ooo`3oool03`3oool002h0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000006`3oool002h0oooo00<000000?ooo`3oool0/`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000006`3oool002h0oooo00<000000?oo
o`3oool0/`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000006`3oool0
02h0oooo0P00002e0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000K0?ooo`00;P3oool0
0`000000oooo0?ooo`2d0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000K0?ooo`00;P3o
ool00`000000oooo0?ooo`2d0?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000001/0oooo
000^0?ooo`030000003oool0oooo0;D0oooo0P0000000`3oool000000?ooo`090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000001/0oooo
000^0?ooo`030000003oool0oooo0;H0oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000K0?ooo`00;P3oool00`000000oooo0?oo
o`330?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`00000K0?ooo`00;P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000K0?ooo`00;P3oool200000<D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000001/0oooo
000^0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo000001/0oooo000^0?ooo`030000003oool0oooo0<@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000001/0oooo
000^0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0000001`0oooo00080?ooo`8000000`3oool00`000000oooo0?ooo`05
00000080oooo0P00000E0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0000001`0oooo00070?ooo`040000003oool0oooo
000000<0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000001@0oooo
00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`000000703oool000X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000030?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool0a03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000703oool000P0oooo
0P0000040?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo0?ooo`00000D0?oo
o`800000a@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`000000703oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool20000
00<0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`350?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0000000L0?ooo`00203oool3000000H0oooo0P000004
0?ooo`800000203oool300000080oooo0`0000050?ooo`030000003oool0oooo0<D0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0000001`0oooo000R0?ooo`040000003oool0
oooo0?ooo`8000001P3oool00`000000oooo0?ooo`350?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0000000L0?ooo`00703oool3000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0<D0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0000001`0oooo000R0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`350?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0000000L0?ooo`008@3oool2000000<0oooo0`0000050?ooo`030000003o
ool0oooo0<D0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0000001`0oooo
000^0?ooo`800000aP3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`000000
703oool002h0oooo00<000000?ooo`3oool0a@3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool06`3oool002h0oooo00<000000?ooo`3oool0aP3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo0<H0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`0K0?ooo`00;P3oool00`000000oooo0?ooo`36
0?ooo`030000003oool0000002H0oooo000^0?ooo`030000003oool0oooo0<H0oooo00<000000?oo
o`0000009P3oool002h0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0000000V0?ooo`00
;P3oool200000<L0oooo00<000000?ooo`0000009P3oool002h0oooo00<000000?ooo`3oool0aP3o
ool00`000000oooo0000000V0?ooo`00;P3oool00`000000oooo0?ooo`360?ooo`030000003oool0
000002H0oooo000^0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`0000009P3oool002h0
oooo00<000000?ooo`3oool0aP3oool00`000000oooo0000000V0?ooo`00;P3oool00`000000oooo
0?ooo`360?ooo`030000003oool0000002H0oooo000^0?ooo`030000003oool0oooo0<H0oooo00<0
00000?ooo`0000009P3oool002h0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0000000V
0?ooo`00;P3oool200000<P0oooo00<000000?ooo`3oool09@3oool002h0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0U0?ooo`00;P3oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo02D0oooo000^0?ooo`030000003oool0oooo0>l0oooo000^0?ooo`030000003oool0
oooo0>l0oooo000^0?ooo`030000003oool0oooo0>l0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8240.08, -1.40389*^-11, \
177.354, 1.41305*^-13}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell["\<\
As a final example, to demonstrate the flexibility of NDSolve, I give an \
example of how you can add a simple method to NDSolve.  In principle, with \
this mechanism, it will be possible to add specialized methods for particular \
types of equations.\
\>", "Text"],

Cell["\<\
\:6700\:5f8c\:306e\:4f8b\:306f\:ff0cNDSolve \:306e\:67d4\:8edf\:6027\:3092\
\:793a\:3059\:305f\:3081\:306b\:ff0c NDSolve \:306b\:7c21\:5358\:306a\:89e3\
\:6cd5\:3092\:4ed8\:52a0\:3059\:308b\:65b9\:6cd5\:3092\:793a\:3057\:307e\:3059\
\:ff0e\:539f\:7406\:7684\:306b\:306f\:ff0c\:3053\:306e\:6a5f\:80fd\:306b\:3088\
\:3063\:3066\:ff0c\:554f\:984c\:306e\:65b9\:7a0b\:5f0f\:306b\:7279\:5316\:3057\
\:305f\:89e3\:6cd5\:3092\:4ed8\:52a0\:3059\:308b\:3053\:3068\:304c\:3067\:304d\
\:307e\:3059\:ff0e\
\>", "Text"],

Cell["\<\
This defines a method function to take a single step towards integrating an \
ODE using the classical fourth order RungeKutta method.  Since the method is \
so simple, it is not necessary to save any private data.\
\>", "MathCaption"],

Cell["\<\
\:3053\:308c\:306f\:ff0c\:53e4\:5178\:7684\:306a\:ff14\:6b21\:306e \
Runge-Kutta \
\:6cd5\:3092\:4f7f\:3063\:3066\:5e38\:5fae\:5206\:65b9\:7a0b\:5f0f\:306e\:ff11\
\:30b9\:30c6\:30c3\:30d7\:3092\:6c42\:3081\:308b\:65b9\:6cd5\:3092\:5b9a\:7fa9\
\:3059\:308b\:95a2\:6570\:3067\:3059\:ff0e\:7c21\:5358\:306a\:65b9\:6cd5\:3067\
\:3059\:304b\:3089\:ff0c\:5185\:90e8\:306b\:4f55\:3089\:30c7\:30fc\:30bf\:3092\
\:6301\:3063\:3066\:3044\:308b\:5fc5\:8981\:304c\:3042\:308a\:307e\:305b\:3093\
\:ff0e\
\>", "MathCaption"],

Cell[BoxData[
    \(\(CRK4[]\)["\<Step\>"[rhs_, \ t_, \ h_, \ y_, \ yp_]]\  := 
      Module[{k0, k1, k2, k3}, \[IndentingNewLine]k0 = 
          h\ yp; \[IndentingNewLine]k1 = 
          h\ rhs[t + h/2, y + k0/2]; \[IndentingNewLine]k2 = 
          h\ rhs[t + h/2, y + k1/2]; \[IndentingNewLine]k3 = 
          h\ rhs[t + h, 
              y + k2]; \[IndentingNewLine]{h, \ \((k0 + 2\ \ k1 + 2\ \ k2 + 
                k3)\)/6}]\)], "Input",
  CellLabel->"In[79]:="],

Cell["\<\
This defines a method function so that NDSolve can obtain the proper \
difference order to use for the method.  The ___ template is used because the \
difference order for the method is always 4.\
\>", "MathCaption"],

Cell["\<\
\:3053\:308c\:306f\:ff0c NDSolve \:304c\:9069\:5207\:306a\:5dee\:5206\:306e\
\:6b21\:6570\:3092\:5f97\:308b\:305f\:3081\:306e\:5b9a\:7fa9\:3092\:4e0e\:3048\
\:308b\:65b9\:6cd5\:95a2\:6570\:3067\:3059\:ff0e\:3053\:306e\:65b9\:6cd5\:306e\
\:6b21\:6570\:306f\:5e38\:306b\:ff14\:3067\:3059\:304b\:3089\:ff0c ___ \:30d1\
\:30bf\:30fc\:30f3\:3092\:4f7f\:3044\:307e\:3059\:ff0e\
\>", "MathCaption"],

Cell[BoxData[
    \(\(CRK4[___]\)["\<DifferenceOrder\>"[]]\  := \ 4\)], "Input",
  CellLabel->"In[80]:="],

Cell["\<\
This defines a method function for the step mode so that NDSolve will know \
how to control time steps.  This algorithm method does not \
\>", "MathCaption"],

Cell["\<\
NDSolve \:304c\:6642\:9593\:306e\:30b9\:30c6\:30c3\:30d7\:3092\:5236\:5fa1\
\:3059\:308b\:305f\:3081\:306e\:30b9\:30c6\:30c3\:30d7\:30e2\:30fc\:30c9\:3092\
\:5b9a\:7fa9\:3059\:308b\:65b9\:6cd5\:95a2\:6570\:3067\:3059\:ff0e\
\>", "MathCaption"],

Cell[BoxData[
    \(\(CRK4[___]\)["\<Stepmode\>"[]]\  := \ Fixed\)], "Input",
  CellLabel->"In[81]:="],

Cell["\<\
This integrates the simple harmonic oscillator equation with fixed step size.\
\
\>", "MathCaption"],

Cell["\:7c21\:5358\:306a\:5358\:632f\:52d5\:306e\:65b9\:7a0b\:5f0f\:3092\:4e00\
\:5b9a\:306e\:30b9\:30c6\:30c3\:30d7\:30b5\:30a4\:30ba\:3067\:89e3\:304d\:307e\
\:3059\:ff0e", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fixed\  = \ 
      NDSolve[{\(x''\)[t]\  + \ x[t]\  \[Equal] \ 0, \ 
          x[0]\  \[Equal] \ 1, \ \(x'\)[0]\  \[Equal] \ 0}, 
        x, {t, 0, 2\ \[Pi]}, \ Method \[Rule] CRK4]\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 6.283185307179586`}}, "<>"]\),
            
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[82]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                CounterBox["SlideShowNavigationBar", "LastSlide"]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar"],

Cell[TextData[{
  "Generally using a fixed step size is less efficient than allowing the step \
size to vary with the local difficulty of the integration.  Most ",
  StyleBox["NDSolve", "MR"],
  " methods have error estimators which makes it possible to very efficiently \
determine appropriate step sizes.  However, for methods without good error \
estimators, an alternative is to use built in step controller methods which \
use extrapolation.  The method ",
  StyleBox["DoubleStep", "MR"],
  " uses an extrapolation based on integrating a time step with a single step \
of size h and two steps of size h/2. "
}], "Text"],

Cell[TextData[{
  "\:4e00\:822c\:306b\:ff0c\:56fa\:5b9a\:30b9\:30c6\:30c3\:30d7\:30b5\:30a4\
\:30ba\:3067\:306f\:ff0c\:7a4d\:5206\:306e\:5c40\:6240\:7684\:96e3\:6613\:5ea6\
\:306b\:5408\:308f\:305b\:3066\:30b9\:30c6\:30c3\:30d7\:30b5\:30a4\:30ba\:3092\
\:5909\:5316\:3055\:305b\:308b\:65b9\:6cd5\:3088\:308a\:52b9\:7387\:304c\:60aa\
\:3044\:3067\:3059\:ff0e\:307b\:3068\:3093\:3069\:306e NDSolve \:306e\:65b9\
\:6cd5\:3067\:306f\:ff0c\:9069\:5207\:306a\:30b9\:30c6\:30c3\:30d7\:30b5\:30a4\
\:30ba\:3092\:9078\:3076\:305f\:3081\:306e\:8aa4\:5dee\:4e88\:6e2c\:6a5f\:80fd\
\:3092\:6301\:3063\:3066\:3044\:307e\:3059\:ff0e\:3088\:3044\:8aa4\:5dee\:4e88\
\:6e2c\:6a5f\:80fd\:3092\:5099\:3048\:3066\:3044\:306a\:3044\:65b9\:6cd5\:3067\
\:306f\:ff0c\:5916\:633f\:3092\:5229\:7528\:3059\:308b\:7d44\:8fbc\:307f\:30b9\
\:30c6\:30c3\:30d7\:30b3\:30f3\:30c8\:30ed\:30fc\:30e9\:3092\:4f7f\:3046\:3053\
\:3068\:3082\:3067\:304d\:307e\:3059\:ff0e",
  StyleBox["DoubleStep", "MR"],
  " \:3068\:3044\:3046\:65b9\:6cd5\:306f\:ff0c\:30b5\:30a4\:30ba h \:306e\
\:ff11\:30b9\:30c6\:30c3\:30d7\:3068\:30b5\:30a4\:30ba h/2 \:306e\:ff12\:6642\
\:9593\:30b9\:30c6\:30c3\:30d7\:306b\:57fa\:3065\:304f\:5916\:633f\:3092\:7528\
\:3044\:307e\:3059\:ff0e"
}], "Text"],

Cell["\<\
The more sophisticated step controller needs to have some additional method \
properties set.  This indicates that the method is not symmetric and is \
explicit.\
\>", "MathCaption"],

Cell["\<\
\:3082\:3063\:3068\:9ad8\:5ea6\:306a\:30b9\:30c6\:30c3\:30d7\:30b3\:30f3\:30c8\
\:30ed\:30fc\:30e9\:306f\:ff0c\:3055\:3089\:306b\:3055\:307e\:3056\:307e\:306a\
\:5c5e\:6027\:3092\:3082\:3063\:3066\:3044\:307e\:3059\:ff0e\:3053\:308c\:306f\
\:ff0c\:89e3\:6cd5\:304c\:5bfe\:79f0\:7684\:3067\:306a\:304f\:ff0c\:307e\:305f\
\:967d\:306a\:5f62\:3067\:306a\:3044\:3053\:3068\:3092\:793a\:3057\:3066\:3044\
\:307e\:3059\:ff0e\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(\(CRK4[___]\)["\<SymmetricMethodQ\>"[]]\  := \ 
        False;\)\), "\[IndentingNewLine]", 
    \(\(\(CRK4[___]\)["\<StiffMethodQ\>"[]]\  := \ 
        False;\)\), "\[IndentingNewLine]", 
    \(\(\(CRK4[___]\)["\<LinearStabilityBoundary\>"[]]\  := \ \
\(-1000\);\)\)}], "Input",
  CellLabel->"In[83]:="],

Cell[TextData[{
  "This integrates the simple harmonic oscillator using the classical fourth \
order Runge-Kutta method with steps controlled by using the ",
  StyleBox["DoubleStep", "MR"],
  " method."
}], "MathCaption"],

Cell[TextData[{
  "\:3075\:3064\:3046\:306e\:5358\:632f\:52d5\:65b9\:7a0b\:5f0f\:3092\:53e4\
\:5178\:7684\:306a\:ff14\:6b21 Runge-Kutta \:6cd5\:3067\:ff0c ",
  StyleBox["DoubleStep", "MR"],
  " \:6cd5\:3092\:30b9\:30c6\:30c3\:30d7\:30b3\:30f3\:30c8\:30ed\:30fc\:30e9\
\:3068\:3057\:3066\:89e3\:304d\:307e\:3059\:ff0e"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dstep\  = \ 
      NDSolve[{\(x''\)[t]\  + \ x[t]\  \[Equal] \ 0, \ 
          x[0]\  \[Equal] \ 1, \ \(x'\)[0]\  \[Equal] \ 0}, 
        x, {t, 0, 2\ \[Pi]}, \ 
        Method \[Rule] {DoubleStep, \ Method \[Rule] CRK4}]\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 6.283185307179586`}}, "<>"]\),
            
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[86]="]
}, Open  ]],

Cell["\<\
This makes a plot comparing the error in the computed solutions at the step \
ends.  The error for the DoubleStep method is shown in blue.\
\>", "MathCaption",
  CellTags->"LastSlide"],

Cell["\<\
\:30b9\:30c6\:30c3\:30d7\:306e\:7d42\:7aef\:3067\:6c42\:3081\:3089\:308c\:305f\
\:89e3\:306e\:8aa4\:5dee\:3092\:30d7\:30ed\:30c3\:30c8\:3057\:3066\:307f\:307e\
\:3059\:ff0e DoubleStep \
\:6cd5\:306b\:3088\:308b\:8aa4\:5dee\:3092\:9752\:3044\:7dda\:3067\:793a\:3057\
\:307e\:3059\:ff0e\
\>", "MathCaption",
  CellTags->"LastSlide"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ploterror[{sol_}, \ opts___]\  := \ 
        Module[{\[IndentingNewLine]points\  = \ 
              x@Coordinates[1]\  /. \ sol, \ \[IndentingNewLine]values\  = \ 
              x@ValuesOnGrid[]\  /. \ sol}, \ \[IndentingNewLine]ListPlot[
            Transpose[{points, \ values\  - \ Cos[points]}], \ 
            opts]\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(Show[
        Block[{$DisplayFunction\  = \ 
              Identity}, {\[IndentingNewLine]ploterror[
              fixed], \[IndentingNewLine]ploterror[dstep, \ 
              PlotStyle \[Rule] 
                RGBColor[0, 0, 1]]\[IndentingNewLine]}]];\)\)}], "Input",
  CellLabel->"In[87]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.353883 1.0058e+007 [
[.17539 .34138 -3 -9 ]
[.17539 .34138 3 0 ]
[.32696 .34138 -3 -9 ]
[.32696 .34138 3 0 ]
[.47854 .34138 -3 -9 ]
[.47854 .34138 3 0 ]
[.63011 .34138 -3 -9 ]
[.63011 .34138 3 0 ]
[.78169 .34138 -3 -9 ]
[.78169 .34138 3 0 ]
[.93327 .34138 -3 -9 ]
[.93327 .34138 3 0 ]
[.01131 .05214 -39 -6.25 ]
[.01131 .05214 0 6.25 ]
[.01131 .15272 -39 -6.25 ]
[.01131 .15272 0 6.25 ]
[.01131 .2533 -39 -6.25 ]
[.01131 .2533 0 6.25 ]
[.01131 .45446 -33 -6.25 ]
[.01131 .45446 0 6.25 ]
[.01131 .55504 -33 -6.25 ]
[.01131 .55504 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .35388 m
.17539 .36013 L
s
[(1)] .17539 .34138 0 1 Mshowa
.32696 .35388 m
.32696 .36013 L
s
[(2)] .32696 .34138 0 1 Mshowa
.47854 .35388 m
.47854 .36013 L
s
[(3)] .47854 .34138 0 1 Mshowa
.63011 .35388 m
.63011 .36013 L
s
[(4)] .63011 .34138 0 1 Mshowa
.78169 .35388 m
.78169 .36013 L
s
[(5)] .78169 .34138 0 1 Mshowa
.93327 .35388 m
.93327 .36013 L
s
[(6)] .93327 .34138 0 1 Mshowa
.125 Mabswid
.05412 .35388 m
.05412 .35763 L
s
.08444 .35388 m
.08444 .35763 L
s
.11476 .35388 m
.11476 .35763 L
s
.14507 .35388 m
.14507 .35763 L
s
.2057 .35388 m
.2057 .35763 L
s
.23602 .35388 m
.23602 .35763 L
s
.26633 .35388 m
.26633 .35763 L
s
.29665 .35388 m
.29665 .35763 L
s
.35728 .35388 m
.35728 .35763 L
s
.38759 .35388 m
.38759 .35763 L
s
.41791 .35388 m
.41791 .35763 L
s
.44822 .35388 m
.44822 .35763 L
s
.50885 .35388 m
.50885 .35763 L
s
.53917 .35388 m
.53917 .35763 L
s
.56948 .35388 m
.56948 .35763 L
s
.5998 .35388 m
.5998 .35763 L
s
.66043 .35388 m
.66043 .35763 L
s
.69074 .35388 m
.69074 .35763 L
s
.72106 .35388 m
.72106 .35763 L
s
.75137 .35388 m
.75137 .35763 L
s
.81201 .35388 m
.81201 .35763 L
s
.84232 .35388 m
.84232 .35763 L
s
.87264 .35388 m
.87264 .35763 L
s
.90295 .35388 m
.90295 .35763 L
s
.96358 .35388 m
.96358 .35763 L
s
.9939 .35388 m
.9939 .35763 L
s
.25 Mabswid
0 .35388 m
1 .35388 L
s
.02381 .05214 m
.03006 .05214 L
s
gsave
.01131 .05214 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .15272 m
.03006 .15272 L
s
gsave
.01131 .15272 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .2533 m
.03006 .2533 L
s
gsave
.01131 .2533 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .45446 m
.03006 .45446 L
s
gsave
.01131 .45446 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .55504 m
.03006 .55504 L
s
gsave
.01131 .55504 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.125 Mabswid
.02381 .07226 m
.02756 .07226 L
s
.02381 .09237 m
.02756 .09237 L
s
.02381 .11249 m
.02756 .11249 L
s
.02381 .13261 m
.02756 .13261 L
s
.02381 .17284 m
.02756 .17284 L
s
.02381 .19295 m
.02756 .19295 L
s
.02381 .21307 m
.02756 .21307 L
s
.02381 .23319 m
.02756 .23319 L
s
.02381 .27342 m
.02756 .27342 L
s
.02381 .29353 m
.02756 .29353 L
s
.02381 .31365 m
.02756 .31365 L
s
.02381 .33377 m
.02756 .33377 L
s
.02381 .374 m
.02756 .374 L
s
.02381 .39411 m
.02756 .39411 L
s
.02381 .41423 m
.02756 .41423 L
s
.02381 .43435 m
.02756 .43435 L
s
.02381 .47458 m
.02756 .47458 L
s
.02381 .49469 m
.02756 .49469 L
s
.02381 .51481 m
.02756 .51481 L
s
.02381 .53493 m
.02756 .53493 L
s
.02381 .03203 m
.02756 .03203 L
s
.02381 .01191 m
.02756 .01191 L
s
.02381 .57516 m
.02756 .57516 L
s
.02381 .59527 m
.02756 .59527 L
s
.02381 .61539 m
.02756 .61539 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .35388 Mdot
.02839 .35389 Mdot
.03298 .35403 Mdot
.03756 .3543 Mdot
.04214 .35469 Mdot
.04673 .35521 Mdot
.05131 .35586 Mdot
.0559 .35663 Mdot
.06048 .35753 Mdot
.06506 .35855 Mdot
.06965 .35968 Mdot
.07423 .36094 Mdot
.07881 .36231 Mdot
.0834 .36379 Mdot
.08798 .36539 Mdot
.09256 .36709 Mdot
.09715 .3689 Mdot
.10173 .3708 Mdot
.10632 .37281 Mdot
.1109 .37491 Mdot
.11548 .3771 Mdot
.12007 .37938 Mdot
.12465 .38173 Mdot
.12923 .38417 Mdot
.13382 .38668 Mdot
.1384 .38925 Mdot
.14299 .39189 Mdot
.14757 .39459 Mdot
.15215 .39734 Mdot
.15674 .40013 Mdot
.16132 .40297 Mdot
.1659 .40585 Mdot
.17049 .40875 Mdot
.17507 .41169 Mdot
.17965 .41464 Mdot
.18424 .4176 Mdot
.18882 .42057 Mdot
.19341 .42355 Mdot
.19799 .42652 Mdot
.20257 .42947 Mdot
.20716 .43241 Mdot
.21174 .43533 Mdot
.21632 .43822 Mdot
.22091 .44107 Mdot
.22549 .44388 Mdot
.23008 .44664 Mdot
.23466 .44934 Mdot
.23924 .45198 Mdot
.24383 .45456 Mdot
.24841 .45706 Mdot
.25299 .45949 Mdot
.25758 .46182 Mdot
.26216 .46407 Mdot
.26674 .46622 Mdot
.27133 .46826 Mdot
.27591 .47019 Mdot
.2805 .47201 Mdot
.28508 .47371 Mdot
.28966 .47529 Mdot
.29425 .47673 Mdot
.29883 .47803 Mdot
.30341 .4792 Mdot
.308 .48022 Mdot
.31258 .48108 Mdot
.31716 .4818 Mdot
.32175 .48235 Mdot
.32633 .48274 Mdot
.33092 .48296 Mdot
.3355 .48301 Mdot
.34008 .48288 Mdot
.34467 .48258 Mdot
.34925 .48209 Mdot
.35383 .48142 Mdot
.35842 .48057 Mdot
.363 .47952 Mdot
.36759 .47828 Mdot
.37217 .47685 Mdot
.37675 .47523 Mdot
.38134 .4734 Mdot
.38592 .47138 Mdot
.3905 .46916 Mdot
.39509 .46674 Mdot
.39967 .46413 Mdot
.40425 .46131 Mdot
.40884 .45829 Mdot
.41342 .45507 Mdot
.41801 .45165 Mdot
.42259 .44804 Mdot
.42717 .44423 Mdot
.43176 .44023 Mdot
.43634 .43603 Mdot
.44092 .43164 Mdot
.44551 .42706 Mdot
.45009 .4223 Mdot
.45468 .41735 Mdot
.45926 .41223 Mdot
.46384 .40693 Mdot
.46843 .40145 Mdot
.47301 .39581 Mdot
.47759 .39001 Mdot
.48218 .38404 Mdot
.48676 .37792 Mdot
.49134 .37166 Mdot
.49593 .36524 Mdot
.50051 .35869 Mdot
.5051 .35201 Mdot
.50968 .3452 Mdot
.51426 .33827 Mdot
.51885 .33123 Mdot
.52343 .32408 Mdot
.52801 .31683 Mdot
.5326 .30948 Mdot
.53718 .30205 Mdot
.54177 .29455 Mdot
.54635 .28697 Mdot
.55093 .27934 Mdot
.55552 .27164 Mdot
.5601 .26391 Mdot
.56468 .25613 Mdot
.56927 .24833 Mdot
.57385 .24051 Mdot
.57843 .23267 Mdot
.58302 .22484 Mdot
.5876 .21701 Mdot
.59219 .20919 Mdot
.59677 .20141 Mdot
.60135 .19365 Mdot
.60594 .18594 Mdot
.61052 .17829 Mdot
.6151 .1707 Mdot
.61969 .16318 Mdot
.62427 .15574 Mdot
.62886 .14839 Mdot
.63344 .14114 Mdot
.63802 .13401 Mdot
.64261 .12699 Mdot
.64719 .1201 Mdot
.65177 .11336 Mdot
.65636 .10676 Mdot
.66094 .10031 Mdot
.66552 .09404 Mdot
.67011 .08794 Mdot
.67469 .08202 Mdot
.67928 .0763 Mdot
.68386 .07078 Mdot
.68844 .06547 Mdot
.69303 .06039 Mdot
.69761 .05552 Mdot
.70219 .0509 Mdot
.70678 .04652 Mdot
.71136 .04239 Mdot
.71594 .03852 Mdot
.72053 .03491 Mdot
.72511 .03158 Mdot
.7297 .02853 Mdot
.73428 .02577 Mdot
.73886 .0233 Mdot
.74345 .02113 Mdot
.74803 .01927 Mdot
.75261 .01771 Mdot
.7572 .01648 Mdot
.76178 .01556 Mdot
.76637 .01497 Mdot
.77095 .01472 Mdot
.77553 .01479 Mdot
.78012 .01521 Mdot
.7847 .01596 Mdot
.78928 .01706 Mdot
.79387 .01851 Mdot
.79845 .02031 Mdot
.80303 .02246 Mdot
.80762 .02496 Mdot
.8122 .02782 Mdot
.81679 .03103 Mdot
.82137 .0346 Mdot
.82595 .03853 Mdot
.83054 .04281 Mdot
.83512 .04744 Mdot
.8397 .05243 Mdot
.84429 .05778 Mdot
.84887 .06347 Mdot
.85346 .06951 Mdot
.85804 .0759 Mdot
.86262 .08263 Mdot
.86721 .0897 Mdot
.87179 .09711 Mdot
.87637 .10485 Mdot
.88096 .11292 Mdot
.88554 .1213 Mdot
.89012 .13001 Mdot
.89471 .13902 Mdot
.89929 .14834 Mdot
.90388 .15796 Mdot
.90846 .16787 Mdot
.91304 .17807 Mdot
.91763 .18854 Mdot
.92221 .19928 Mdot
.92679 .21028 Mdot
.93138 .22153 Mdot
.93596 .23303 Mdot
.94055 .24475 Mdot
.94513 .25671 Mdot
.94971 .26887 Mdot
.9543 .28124 Mdot
.95888 .2938 Mdot
.96346 .30654 Mdot
.96805 .31946 Mdot
.97212 .3311 Mdot
.97619 .34283 Mdot
0 0 1 r
.02381 .35388 Mdot
.03202 .35394 Mdot
.04756 .35664 Mdot
.0634 .35957 Mdot
.07955 .36267 Mdot
.09603 .36585 Mdot
.11287 .36901 Mdot
.13009 .37199 Mdot
.14776 .37462 Mdot
.16592 .37666 Mdot
.18404 .3771 Mdot
.20162 .37548 Mdot
.21871 .37224 Mdot
.23538 .36774 Mdot
.25166 .36228 Mdot
.26758 .35609 Mdot
.28317 .34939 Mdot
.29896 .34204 Mdot
.31506 .33398 Mdot
.33148 .32515 Mdot
.34826 .3155 Mdot
.36542 .30496 Mdot
.38301 .29344 Mdot
.40109 .2808 Mdot
.4193 .26782 Mdot
.43696 .25635 Mdot
.45413 .24654 Mdot
.47086 .23847 Mdot
.4872 .23217 Mdot
.50318 .22763 Mdot
.51882 .22483 Mdot
.53456 .22333 Mdot
.55061 .22307 Mdot
.56698 .22417 Mdot
.5837 .22677 Mdot
.6008 .23106 Mdot
.61832 .2372 Mdot
.63632 .24544 Mdot
.65463 .25619 Mdot
.67237 .26981 Mdot
.68961 .28564 Mdot
.70641 .3031 Mdot
.7228 .32172 Mdot
.73883 .34108 Mdot
.75452 .36083 Mdot
.77022 .38111 Mdot
.78622 .40215 Mdot
.80254 .42385 Mdot
.81921 .4461 Mdot
.83625 .4688 Mdot
.8537 .49183 Mdot
.87162 .51513 Mdot
.89002 .53853 Mdot
.90784 .55874 Mdot
.92516 .57562 Mdot
.94201 .58914 Mdot
.95847 .59932 Mdot
.96733 .60174 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[87]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00:P3oool00`000000oooo0?ooo`3c0?ooo`00:P3oool00`000000oooo0?ooo`3c0?ooo`00
:P3oool00`000000oooo0?ooo`3c0?ooo`00:P3oool200000;@0oooo100000000`3oool000000000
0003000003H0oooo000Z0?ooo`030000003oool0oooo0;40oooo1P0000000`3oool0000000000005
000003@0oooo000Z0?ooo`030000003oool0oooo0:h0oooo0P0000000`3oool000000000000:0?oo
o`80000000<0oooo000000000000<@3oool002X0oooo00<000000?ooo`3oool0[@3oool300000100
oooo0`00000`0?ooo`00:P3oool00`000000oooo0?ooo`2/0?ooo`800000503oool2000002l0oooo
000Z0?ooo`800000[03oool2000001H0oooo0P00000^0?ooo`00203oool2000000<0oooo00<00000
0?ooo`3oool01@0000020?ooo`8000004@3oool00`000000oooo0?ooo`2Z0?ooo`800000603oool2
000002d0oooo00070?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000oooo0000
00030?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0Z@3oool2000001X0oooo
0P00000/0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`2W0?ooo`030000003oool0000001`0
oooo00<000000?ooo`000000:P3oool000030?ooo`0000000000008000001@3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo00000100oooo00<0
00000?ooo`3oool0YP3oool200000200oooo0P00000Y0?ooo`001`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`00000@0?ooo`80
0000YP3oool200000280oooo00<000000?ooo`3oool09`3oool000P0oooo0P0000070?ooo`800000
103oool200000140oooo00<000000?ooo`3oool0Y03oool2000002@0oooo00<000000?ooo`3oool0
9P3oool00240oooo0`0000060?ooo`030000003oool0oooo0:<0oooo0P00000U0?ooo`8000009`3o
ool00240oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0
oooo02D0oooo0P00000V0?ooo`00703oool3000000<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2R0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0903oool00240
oooo00<000000?ooo`0000001P3oool200000:80oooo0P00000Z0?ooo`030000003oool0oooo02<0
oooo000Q0?ooo`<000001P3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool08`3oool002X0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0240oooo000Z0?ooo`030000003oool0oooo09h0oooo0P00000_
0?ooo`030000003oool0oooo0240oooo000Z0?ooo`030000003oool0oooo09h0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0P0?ooo`00:P3oool2000009h0oooo00<000000?ooo`3o
ool0<03oool200000240oooo000Z0?ooo`030000003oool0oooo09`0oooo0P00000c0?ooo`030000
003oool0oooo01l0oooo000Z0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0N0?ooo`00:P3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool07P3oool002X0oooo00<000000?ooo`3oool0VP3oool20000
03L0oooo00<000000?ooo`3oool07@3oool002X0oooo0P00002K0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool07@3oool002X0oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo01`0oooo000Z0?ooo`030000003oool0oooo09T0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0L0?ooo`00:P3oool00`000000oooo0?ooo`2G
0?ooo`030000003oool0oooo05T0oooo000Z0?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0K0?ooo`00:P3oool2000009L0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0K0?ooo`00:P3oool00`000000oooo0?ooo`2E0?ooo`800000
@03oool00`000000oooo0?ooo`0I0?ooo`001`3oool400000080oooo00<000000?ooo`3oool01@00
00020?ooo`8000004@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool06@3oool000L0oooo00<000000?ooo`3oool0103oool01@000000oooo0000003o
ool0000000<0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0603oool000P0oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3o
ool0U03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01P0oooo00000`3oool00000
00000002000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0
oooo00@000000?ooo`3oool00000403oool2000009@0oooo00<000000?ooo`3oool0G@3oool000L0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool2000000<0oooo00@00000
0?ooo`3oool00000403oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool05`3oool000P0oooo0P0000070?ooo`800000103oool2000000P0oooo0`000006
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0G
0?ooo`008@3oool00`000000oooo000000060?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0F0?ooo`00703oool3000000<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool05P3oool00240oooo00<000000?ooo`0000001P3oool200000940oooo00<000000?ooo`3oool0
H03oool00240oooo0`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0E0?ooo`00:P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool05@3oool002X0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo01@0oooo000Z0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0D0?ooo`00:P3oool2000008h0oooo
00<000000?ooo`3oool0H`3oool002X0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo01<0oooo000Z0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0C0?ooo`00:P3oool00`000000oooo0?ooo`2;0?oo
o`800000IP3oool002X0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo0140oooo000Z0?ooo`800000R`3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0140oooo000Z0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0IP3o
ool002X0oooo00<000000?ooo`3oool0N03oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00D0
003o0?ooo`3oool0oooo0000o`030?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
403oool002X0oooo00<000000?ooo`3oool0M03oool01@000?l0oooo0?ooo`3oool0003o00<0oooo
00D0003o0?ooo`3oool0oooo0000o`030?ooo`060000o`3oool0oooo0?ooo`000000003oEP3oool0
0`000000oooo0?ooo`0@0?ooo`00:P3oool00`000000oooo0?ooo`1`0?ooo`050000o`3oool0oooo
0?ooo`000?l04P3oool00`000000oooo0000o`030?ooo`030000o`3oool0oooo0540oooo00<00000
0?ooo`3oool03`3oool002X0oooo0P00001a0?ooo`030000o`3oool0oooo01@0oooo00<000000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0oooo00l0oooo000Z0?ooo`03
0000003oool0oooo06`0oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`03
0000o`3oool0oooo05l0oooo00070?ooo`D0000000@0oooo0000003oool0oooo1@0000020?ooo`80
00004@3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo01L0oooo00<000000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo00h0oooo00090?ooo`030000
003oool0oooo0080oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0000
0100oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo
00h0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`0>0?ooo`002@3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000403oool0
0`000000oooo0?ooo`1X0?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`1J0?ooo`0000<0oooo0000000000000P0000040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo00000100oooo0P00
001U0?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`160?ooo`030000003oool0oooo00d0oooo00090?ooo`050000003oool0oooo0?ooo`0000000`3o
ool2000000<0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`1T0?ooo`030000
o`3oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`160?ooo`030000
003oool0oooo00d0oooo00080?ooo`8000001`3oool2000000@0oooo0P0000080?ooo`<000001P3o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo06d0oooo000Q0?ooo`030000003oool0
000000H0oooo00<000000?ooo`3oool0G`3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0
oooo05h0oooo00<000000?ooo`3oool0303oool001`0oooo0`0000030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0G`3oool00`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo
01X0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`0<0?ooo`008@3oool00`000000
oooo000000060?ooo`800000P`3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo0540
oooo000Q0?ooo`<000001P3oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo0280oooo
00<000000?ooo`3oool0L03oool002X0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?oo
o`0R0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02P3oool002X0oooo00<00000
0?ooo`3oool0O`3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0400oooo00<00000
0?ooo`3oool02P3oool002X0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Q0?oo
o`030000o`3oool0oooo04d0oooo000Z0?ooo`800000E`3oool00`000?l0oooo0?ooo`0U0?ooo`03
0000003oool0oooo06H0oooo00<000000?ooo`3oool02@3oool002X0oooo00<000000?ooo`3oool0
EP3oool00`000?l0oooo0?ooo`0U0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
2@3oool002X0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo04T0oooo000Z0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool0:03oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0203oool0
02X0oooo00<000000?ooo`3oool08@3oool500000240oooo100000070?ooo`030000o`3oool0oooo
01T0oooo0P00000<0?ooo`030000003oool0oooo01H0oooo0`00000R0?ooo`8000008`3oool30000
00H0oooo00<000000?ooo`3oool0203oool002X0oooo0P00000T0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0L0?ooo`040000003oool0oooo0000
00X0oooo0P00000I0?ooo`030000003oool0oooo0200oooo00@000000?ooo`3oool000008P3oool0
10000000oooo0?ooo`00000@0?ooo`00:P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0N0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool05@3oool5000002@0oooo00<000000?ooo`3oool0803oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo00L0oooo000Z0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`00000D0?ooo`030000o`3o
ool0oooo00`0oooo0P00000S0?ooo`<000001`3oool00`000000oooo0?ooo`070?ooo`00:P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0240oooo00@000000?ooo`000?l000008P3o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`000000
503oool00`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
403oool002X0oooo00<000000?ooo`3oool08P3oool2000002@0oooo00<000000000o`3oool08`3o
ool2000000P0oooo00<000000?ooo`3oool06P3oool2000002<0oooo0`00000S0?ooo`<000001`3o
ool00`000000oooo0?ooo`060?ooo`00:P3oool2000004H0oooo00<0003o0?ooo`3oool0<03oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo000Z0?ooo`030000003oool0oooo
04D0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`1i0?ooo`00:P3oool00`000000
oooo0?ooo`110?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0=@3oool00`000?l0
oooo0?ooo`0i0?ooo`030000003oool0oooo00D0oooo000Z0?ooo`030000003oool0oooo0440oooo
00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo03T0oooo
00<000000?ooo`3oool01@3oool002X0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?oo
o`0e0?ooo`800000O03oool002@0oooo1@0000000`000?l000000000o`03000000030000o`000000
000003@0000000D0003o00000000000000000000o`2e00000000:@3oool010000?l000000000o`3o
ool2000000070000o`0000000000000000000?l0oooo000000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00
:P3oool00`000000oooo0?ooo`050?ooo`03000000000?l0oooo0080000000<0003o0000003oool0
5P3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
3`3oool002X0oooo00<000000?ooo`3oool02@3oool00`000000003o00000002000000030000o`3o
ool0oooo0200oooo00D0003o0?ooo`3oool0oooo0000o`0m0?ooo`030000003oool0oooo03d0oooo
00<0003o0?ooo`3oool0?@3oool002X0oooo00<000000?ooo`3oool0303oool2000000050000o`00
000000000?ooo`000?l0103oool00`000?l0oooo0?ooo`0C0?ooo`050000o`3oool0oooo0?ooo`00
0?l0?`3oool00`000000oooo0000001o0?ooo`00:P3oool200000100oooo0`0000000`000?l0oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`060?ooo`05
0000o`3oool0oooo0?ooo`000?l0@`3oool00`000000oooo0?ooo`1o0?ooo`00:P3oool00`000000
oooo0?ooo`0A0?ooo`@000001P3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`000?l0103oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo0800oooo000Z0?ooo`03
0000003oool0oooo01<0oooo0`0000000`3oool000000?ooo`0;0?ooo`030000o`3oool0oooo04P0
oooo0P0000160?ooo`030000o`3oool0oooo03T0oooo000Z0?ooo`030000003oool0oooo01D0oooo
00@000000?ooo`0000000000EP3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo03T0
oooo000Z0?ooo`030000003oool0oooo01P0oooo0`00001C0?ooo`030000003oool0oooo0880oooo
000Z0?ooo`8000006P3oool300000540oooo0P0000240?ooo`00:P3oool00`000000oooo0?ooo`0K
0?ooo`<00000C`3oool00`000000oooo0?ooo`230?ooo`00:P3oool00`000000oooo0?ooo`0L0?oo
o`80000000<0oooo0000003oool0B`3oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo
03D0oooo000Z0?ooo`030000003oool0oooo01l0oooo0P00001:0?ooo`800000CP3oool00`000?l0
oooo0?ooo`0e0?ooo`00:P3oool00`000000oooo0?ooo`0P0?ooo`<00000AP3oool00`000000oooo
000000270?ooo`00:P3oool200000280oooo0`0000150?ooo`030000003oool0oooo08L0oooo000Z
0?ooo`030000003oool0oooo02<0oooo0P0000130?ooo`030000003oool0oooo08P0oooo000Z0?oo
o`030000003oool0oooo02@0oooo00@000000?ooo`0000000000?`3oool2000005H0oooo00<0003o
0?ooo`3oool0<@3oool002X0oooo00<000000?ooo`3oool09P3oool3000003d0oooo0P00001G0?oo
o`030000o`3oool0oooo0340oooo000Z0?ooo`030000003oool0oooo02P0oooo0`00000j0?ooo`80
0000S03oool002X0oooo0P00000Z0?ooo`<00000>03oool2000008d0oooo000Z0?ooo`030000003o
ool0oooo02/0oooo0P00000e0?ooo`030000003oool0000008h0oooo00070?ooo`D0000000@0oooo
0000003oool0oooo1@0000020?ooo`8000004@3oool00`000000oooo0?ooo`0/0?ooo`040000003o
ool0000000000340oooo0P00002@0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`050000003o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo02h0
oooo0`00000_0?ooo`800000HP3oool00`000?l0oooo0?ooo`0/0?ooo`002@3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000403oool00`00
0000oooo0?ooo`0`0?ooo`<00000;03oool2000006<0oooo00<0003o0?ooo`3oool0;03oool000T0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00@000000?oo
o`3oool00000403oool00`000000oooo0?ooo`0a0?ooo`<00000:P3oool2000009<0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00@000000?ooo`3oool00000403o
ool2000003@0oooo0P0000000`3oool000000?ooo`0U0?ooo`800000U03oool000P0oooo0P000007
0?ooo`800000103oool200000140oooo00<000000?ooo`3oool0=03oool00`000000oooo00000002
00000240oooo00@000000?ooo`0000000000U@3oool00240oooo0`0000060?ooo`030000003oool0
oooo03L0oooo1000000N0?ooo`80000000<0oooo0000003oool0U@3oool00240oooo00<000000?oo
o`0000001P3oool00`000000oooo0?ooo`0i0?ooo`<0000000<0oooo0000003oool0603oool30000
06h0oooo00<0003o0?ooo`3oool0:03oool001`0oooo0`0000030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo00000002000001D0oooo1000001_0?ooo`03
0000o`3oool0oooo02P0oooo000Q0?ooo`030000003oool0000000H0oooo0P00000o0?ooo`H00000
3@3oool2000000040?ooo`0000000000000009`0oooo000Q0?ooo`<000001P3oool00`000000oooo
0?ooo`100?ooo`@0000000<0oooo0000000000001@0000000`3oool0000000000004000000030?oo
o`000000oooo09d0oooo000Z0?ooo`030000003oool0oooo04D0oooo1`0000000`3oool000000000
000200000:80oooo000Z0?ooo`030000003oool0oooo0<`0oooo00<0003o0?ooo`3oool0903oool0
02X0oooo00<000000?ooo`3oool0c03oool00`000?l0oooo0?ooo`0T0?ooo`00:P3oool200000?@0
oooo000Z0?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`030000003oool0oooo0?<0oooo000Z
0?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`030000003oool0oooo0=40oooo00<0003o0?oo
o`3oool07`3oool002X0oooo0P00003B0?ooo`030000o`3oool0oooo01l0oooo000Z0?ooo`030000
003oool0oooo0?<0oooo000Z0?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`030000003oool0
oooo0?<0oooo000Z0?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`800000eP3oool00`000?l0
oooo0?ooo`0K0?ooo`001`3oool400000080oooo00<000000?ooo`3oool01@0000020?ooo`800000
4@3oool00`000000oooo0?ooo`3E0?ooo`030000o`3oool0oooo01/0oooo00070?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo00000100
oooo00<000000?ooo`3oool0l`3oool000P0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`0000030?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0l`3oool000T0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00@000000?oo
o`3oool00000403oool00`000000oooo0?ooo`3c0?ooo`001`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`00000@0?ooo`800000
f`3oool00`000?l0oooo0?ooo`0F0?ooo`00203oool2000000L0oooo0P0000040?ooo`8000004@3o
ool00`000000oooo0?ooo`3J0?ooo`030000o`3oool0oooo01H0oooo000Q0?ooo`<000001P3oool0
0`000000oooo0?ooo`3c0?ooo`008@3oool00`000000oooo000000060?ooo`030000003oool0oooo
0?<0oooo000L0?ooo`<000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=h0
oooo00<0003o0?ooo`3oool04P3oool00240oooo00<000000?ooo`0000001P3oool200000=l0oooo
00<0003o0?ooo`3oool04P3oool00240oooo0`0000060?ooo`030000003oool0oooo0?<0oooo000Z
0?ooo`030000003oool0oooo0?<0oooo000Z0?ooo`030000003oool0oooo0>80oooo00<0003o0?oo
o`3oool03P3oool002X0oooo00<000000?ooo`3oool0hP3oool00`000?l0oooo0?ooo`0>0?ooo`00
:P3oool200000>P0oooo00<0003o0?ooo`3oool02@3oool002X0oooo00<000000?ooo`3oool0i`3o
ool01@000?l0oooo0000o`3oool0003o00L0oooo000Z0?ooo`030000003oool0oooo0>T0oooo00<0
003o0?ooo`000?l01`3oool002X0oooo00<000000?ooo`3oool0l`3oool002X0oooo00<000000?oo
o`3oool0l`3oool002X0oooo0P00003d0?ooo`00:P3oool00`000000oooo0?ooo`3c0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.10826, -3.95273*^-08, \
0.0263016, 3.9637*^-10}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 742}},
ScreenStyleEnvironment->"Brackets",
WindowSize->{669, 497},
WindowMargins->{{6, Automatic}, {Automatic, 11}},
Magnification->1.25,
StyleDefinitions -> "5.0 Numerics Style.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:1"->{
    Cell[15741, 405, 212, 5, 52, "Input",
      CellTags->{"b:1", "ndsg:0"}],
    Cell[17130, 444, 153, 3, 52, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],
    Cell[17286, 449, 250, 3, 52, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],
    Cell[17561, 456, 194, 4, 50, "Input",
      CellTags->{"b:1", "ndsg:0"}]},
  "ndsg:0"->{
    Cell[15741, 405, 212, 5, 52, "Input",
      CellTags->{"b:1", "ndsg:0"}],
    Cell[17130, 444, 153, 3, 52, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],
    Cell[17286, 449, 250, 3, 52, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],
    Cell[17561, 456, 194, 4, 50, "Input",
      CellTags->{"b:1", "ndsg:0"}]},
  "S3.9.7"->{
    Cell[17130, 444, 153, 3, 52, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],
    Cell[17286, 449, 250, 3, 52, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}]},
  "7.16"->{
    Cell[17130, 444, 153, 3, 52, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],
    Cell[17286, 449, 250, 3, 52, "MathCaption",
      CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}]},
  "LastSlide"->{
    Cell[71469, 2110, 194, 4, 69, "MathCaption",
      CellTags->"LastSlide"],
    Cell[71666, 2116, 340, 7, 69, "MathCaption",
      CellTags->"LastSlide"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:1", 102001, 2996},
  {"ndsg:0", 102376, 3005},
  {"S3.9.7", 102751, 3014},
  {"7.16", 102968, 3019},
  {"LastSlide", 103190, 3024}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 1594, 41, 28, "SlideShowNavigationBar"],
Cell[3373, 96, 206, 4, 69, "MathCaption"],
Cell[3582, 102, 387, 6, 69, "MathCaption"],
Cell[3972, 110, 205, 4, 69, "Input"],
Cell[4180, 116, 108, 3, 27, "Text"],
Cell[4291, 121, 189, 4, 27, "Text"],
Cell[4483, 127, 105, 2, 52, "MathCaption"],
Cell[4591, 131, 183, 2, 52, "MathCaption"],

Cell[CellGroupData[{
Cell[4799, 137, 473, 10, 107, "Input"],
Cell[5275, 149, 313, 9, 44, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5637, 164, 1594, 41, 28, "SlideShowNavigationBar"],
Cell[7234, 207, 461, 10, 95, "Text"],
Cell[7698, 219, 890, 15, 95, "Text"],
Cell[8591, 236, 660, 10, 129, "Text"],
Cell[9254, 248, 1469, 20, 129, "Text"],
Cell[10726, 270, 84, 1, 52, "MathCaption"],
Cell[10813, 273, 151, 1, 52, "MathCaption"],

Cell[CellGroupData[{
Cell[10989, 278, 638, 13, 164, "Input"],
Cell[11630, 293, 312, 9, 44, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11991, 308, 1594, 41, 28, "SlideShowNavigationBar"],
Cell[13588, 351, 294, 6, 61, "Text"],
Cell[13885, 359, 653, 10, 78, "Text"],
Cell[14541, 371, 174, 3, 69, "MathCaption"],
Cell[14718, 376, 409, 6, 69, "MathCaption"],
Cell[15130, 384, 341, 8, 56, "Input"],
Cell[15474, 394, 102, 2, 31, "Input"],
Cell[15579, 398, 44, 0, 52, "MathCaption"],
Cell[15626, 400, 90, 1, 52, "MathCaption"],

Cell[CellGroupData[{
Cell[15741, 405, 212, 5, 52, "Input",
  CellTags->{"b:1", "ndsg:0"}],
Cell[15956, 412, 559, 15, 63, "Output"]
}, Open  ]],
Cell[16530, 430, 203, 4, 61, "Text"],
Cell[16736, 436, 391, 6, 44, "Text"],
Cell[17130, 444, 153, 3, 52, "MathCaption",
  CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],
Cell[17286, 449, 250, 3, 52, "MathCaption",
  CellTags->{"S3.9.7", "7.16", "b:1", "ndsg:0"}],

Cell[CellGroupData[{
Cell[17561, 456, 194, 4, 50, "Input",
  CellTags->{"b:1", "ndsg:0"}],
Cell[17758, 462, 42240, 1351, 232, 15829, 1020, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[60047, 1819, 1594, 41, 28, "SlideShowNavigationBar"],
Cell[61644, 1862, 275, 5, 61, "Text"],
Cell[61922, 1869, 515, 8, 61, "Text"],
Cell[62440, 1879, 244, 4, 86, "MathCaption"],
Cell[62687, 1885, 520, 9, 86, "MathCaption"],
Cell[63210, 1896, 467, 9, 145, "Input"],
Cell[63680, 1907, 226, 4, 86, "MathCaption"],
Cell[63909, 1913, 401, 6, 69, "MathCaption"],
Cell[64313, 1921, 105, 2, 31, "Input"],
Cell[64421, 1925, 167, 3, 69, "MathCaption"],
Cell[64591, 1930, 253, 4, 52, "MathCaption"],
Cell[64847, 1936, 102, 2, 31, "Input"],
Cell[64952, 1940, 110, 3, 52, "MathCaption"],
Cell[65065, 1945, 189, 2, 52, "MathCaption"],

Cell[CellGroupData[{
Cell[65279, 1951, 239, 5, 50, "Input"],
Cell[65521, 1958, 288, 9, 25, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[65858, 1973, 1594, 41, 28, "SlideShowNavigationBar"],
Cell[67455, 2016, 624, 11, 112, "Text"],
Cell[68082, 2029, 1238, 18, 112, "Text"],
Cell[69323, 2049, 192, 4, 69, "MathCaption"],
Cell[69518, 2055, 449, 7, 69, "MathCaption"],
Cell[69970, 2064, 326, 7, 69, "Input"],
Cell[70299, 2073, 221, 5, 69, "MathCaption"],
Cell[70523, 2080, 336, 6, 69, "MathCaption"],

Cell[CellGroupData[{
Cell[70884, 2090, 279, 6, 50, "Input"],
Cell[71166, 2098, 288, 9, 25, "Output"]
}, Open  ]],
Cell[71469, 2110, 194, 4, 69, "MathCaption",
  CellTags->"LastSlide"],
Cell[71666, 2116, 340, 7, 69, "MathCaption",
  CellTags->"LastSlide"],

Cell[CellGroupData[{
Cell[72031, 2127, 695, 13, 202, "Input"],
Cell[72729, 2142, 28562, 832, 230, 9983, 598, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

